from google.ads.googleads.v8.common.types.ad_asset import (
    AdImageAsset as AdImageAsset,
    AdMediaBundleAsset as AdMediaBundleAsset,
    AdTextAsset as AdTextAsset,
    AdVideoAsset as AdVideoAsset,
)
from google.ads.googleads.v8.common.types.ad_type_infos import (
    AppAdInfo as AppAdInfo,
    AppEngagementAdInfo as AppEngagementAdInfo,
    CallAdInfo as CallAdInfo,
    DisplayCallToAction as DisplayCallToAction,
    DisplayUploadAdInfo as DisplayUploadAdInfo,
    ExpandedDynamicSearchAdInfo as ExpandedDynamicSearchAdInfo,
    ExpandedTextAdInfo as ExpandedTextAdInfo,
    GmailAdInfo as GmailAdInfo,
    GmailTeaser as GmailTeaser,
    HotelAdInfo as HotelAdInfo,
    ImageAdInfo as ImageAdInfo,
    LegacyAppInstallAdInfo as LegacyAppInstallAdInfo,
    LegacyResponsiveDisplayAdInfo as LegacyResponsiveDisplayAdInfo,
    LocalAdInfo as LocalAdInfo,
    ProductImage as ProductImage,
    ProductVideo as ProductVideo,
    ResponsiveDisplayAdControlSpec as ResponsiveDisplayAdControlSpec,
    ResponsiveDisplayAdInfo as ResponsiveDisplayAdInfo,
    ResponsiveSearchAdInfo as ResponsiveSearchAdInfo,
    ShoppingComparisonListingAdInfo as ShoppingComparisonListingAdInfo,
    ShoppingProductAdInfo as ShoppingProductAdInfo,
    ShoppingSmartAdInfo as ShoppingSmartAdInfo,
    SmartCampaignAdInfo as SmartCampaignAdInfo,
    TextAdInfo as TextAdInfo,
    VideoAdInfo as VideoAdInfo,
    VideoBumperInStreamAdInfo as VideoBumperInStreamAdInfo,
    VideoNonSkippableInStreamAdInfo as VideoNonSkippableInStreamAdInfo,
    VideoOutstreamAdInfo as VideoOutstreamAdInfo,
    VideoResponsiveAdInfo as VideoResponsiveAdInfo,
    VideoTrueViewDiscoveryAdInfo as VideoTrueViewDiscoveryAdInfo,
    VideoTrueViewInStreamAdInfo as VideoTrueViewInStreamAdInfo,
)
from google.ads.googleads.v8.common.types.asset_policy import (
    AdAssetPolicySummary as AdAssetPolicySummary,
)
from google.ads.googleads.v8.common.types.asset_types import (
    BookOnGoogleAsset as BookOnGoogleAsset,
    CalloutAsset as CalloutAsset,
    ImageAsset as ImageAsset,
    ImageDimension as ImageDimension,
    LeadFormAsset as LeadFormAsset,
    LeadFormDeliveryMethod as LeadFormDeliveryMethod,
    LeadFormField as LeadFormField,
    LeadFormSingleChoiceAnswers as LeadFormSingleChoiceAnswers,
    MediaBundleAsset as MediaBundleAsset,
    PromotionAsset as PromotionAsset,
    SitelinkAsset as SitelinkAsset,
    StructuredSnippetAsset as StructuredSnippetAsset,
    TextAsset as TextAsset,
    WebhookDelivery as WebhookDelivery,
    YoutubeVideoAsset as YoutubeVideoAsset,
)
from google.ads.googleads.v8.common.types.bidding import (
    Commission as Commission,
    EnhancedCpc as EnhancedCpc,
    ManualCpc as ManualCpc,
    ManualCpm as ManualCpm,
    ManualCpv as ManualCpv,
    MaximizeConversions as MaximizeConversions,
    MaximizeConversionValue as MaximizeConversionValue,
    PercentCpc as PercentCpc,
    TargetCpa as TargetCpa,
    TargetCpm as TargetCpm,
    TargetImpressionShare as TargetImpressionShare,
    TargetRoas as TargetRoas,
    TargetSpend as TargetSpend,
)
from google.ads.googleads.v8.common.types.click_location import (
    ClickLocation as ClickLocation,
)
from google.ads.googleads.v8.common.types.criteria import (
    AddressInfo as AddressInfo,
    AdScheduleInfo as AdScheduleInfo,
    AgeRangeInfo as AgeRangeInfo,
    AppPaymentModelInfo as AppPaymentModelInfo,
    CarrierInfo as CarrierInfo,
    CombinedAudienceInfo as CombinedAudienceInfo,
    ContentLabelInfo as ContentLabelInfo,
    CustomAffinityInfo as CustomAffinityInfo,
    CustomAudienceInfo as CustomAudienceInfo,
    CustomIntentInfo as CustomIntentInfo,
    DeviceInfo as DeviceInfo,
    GenderInfo as GenderInfo,
    GeoPointInfo as GeoPointInfo,
    HotelAdvanceBookingWindowInfo as HotelAdvanceBookingWindowInfo,
    HotelCheckInDateRangeInfo as HotelCheckInDateRangeInfo,
    HotelCheckInDayInfo as HotelCheckInDayInfo,
    HotelCityInfo as HotelCityInfo,
    HotelClassInfo as HotelClassInfo,
    HotelCountryRegionInfo as HotelCountryRegionInfo,
    HotelDateSelectionTypeInfo as HotelDateSelectionTypeInfo,
    HotelIdInfo as HotelIdInfo,
    HotelLengthOfStayInfo as HotelLengthOfStayInfo,
    HotelStateInfo as HotelStateInfo,
    IncomeRangeInfo as IncomeRangeInfo,
    InteractionTypeInfo as InteractionTypeInfo,
    IpBlockInfo as IpBlockInfo,
    KeywordInfo as KeywordInfo,
    KeywordThemeInfo as KeywordThemeInfo,
    LanguageInfo as LanguageInfo,
    ListingDimensionInfo as ListingDimensionInfo,
    ListingGroupInfo as ListingGroupInfo,
    ListingScopeInfo as ListingScopeInfo,
    LocationGroupInfo as LocationGroupInfo,
    LocationInfo as LocationInfo,
    MobileAppCategoryInfo as MobileAppCategoryInfo,
    MobileApplicationInfo as MobileApplicationInfo,
    MobileDeviceInfo as MobileDeviceInfo,
    OperatingSystemVersionInfo as OperatingSystemVersionInfo,
    ParentalStatusInfo as ParentalStatusInfo,
    PlacementInfo as PlacementInfo,
    PreferredContentInfo as PreferredContentInfo,
    ProductBiddingCategoryInfo as ProductBiddingCategoryInfo,
    ProductBrandInfo as ProductBrandInfo,
    ProductChannelExclusivityInfo as ProductChannelExclusivityInfo,
    ProductChannelInfo as ProductChannelInfo,
    ProductConditionInfo as ProductConditionInfo,
    ProductCustomAttributeInfo as ProductCustomAttributeInfo,
    ProductItemIdInfo as ProductItemIdInfo,
    ProductTypeInfo as ProductTypeInfo,
    ProximityInfo as ProximityInfo,
    TopicInfo as TopicInfo,
    UnknownListingDimensionInfo as UnknownListingDimensionInfo,
    UserInterestInfo as UserInterestInfo,
    UserListInfo as UserListInfo,
    WebpageConditionInfo as WebpageConditionInfo,
    WebpageInfo as WebpageInfo,
    WebpageSampleInfo as WebpageSampleInfo,
    YouTubeChannelInfo as YouTubeChannelInfo,
    YouTubeVideoInfo as YouTubeVideoInfo,
)
from google.ads.googleads.v8.common.types.criterion_category_availability import (
    CriterionCategoryAvailability as CriterionCategoryAvailability,
    CriterionCategoryChannelAvailability as CriterionCategoryChannelAvailability,
    CriterionCategoryLocaleAvailability as CriterionCategoryLocaleAvailability,
)
from google.ads.googleads.v8.common.types.custom_parameter import (
    CustomParameter as CustomParameter,
)
from google.ads.googleads.v8.common.types.dates import (
    DateRange as DateRange,
    YearMonth as YearMonth,
    YearMonthRange as YearMonthRange,
)
from google.ads.googleads.v8.common.types.explorer_auto_optimizer_setting import (
    ExplorerAutoOptimizerSetting as ExplorerAutoOptimizerSetting,
)
from google.ads.googleads.v8.common.types.extensions import (
    AffiliateLocationFeedItem as AffiliateLocationFeedItem,
    AppFeedItem as AppFeedItem,
    CallFeedItem as CallFeedItem,
    CalloutFeedItem as CalloutFeedItem,
    HotelCalloutFeedItem as HotelCalloutFeedItem,
    ImageFeedItem as ImageFeedItem,
    LocationFeedItem as LocationFeedItem,
    PriceFeedItem as PriceFeedItem,
    PriceOffer as PriceOffer,
    PromotionFeedItem as PromotionFeedItem,
    SitelinkFeedItem as SitelinkFeedItem,
    StructuredSnippetFeedItem as StructuredSnippetFeedItem,
    TextMessageFeedItem as TextMessageFeedItem,
)
from google.ads.googleads.v8.common.types.feed_common import Money as Money
from google.ads.googleads.v8.common.types.feed_item_set_filter_type_infos import (
    BusinessNameFilter as BusinessNameFilter,
    DynamicAffiliateLocationSetFilter as DynamicAffiliateLocationSetFilter,
    DynamicLocationSetFilter as DynamicLocationSetFilter,
)
from google.ads.googleads.v8.common.types.final_app_url import (
    FinalAppUrl as FinalAppUrl,
)
from google.ads.googleads.v8.common.types.frequency_cap import (
    FrequencyCapEntry as FrequencyCapEntry,
    FrequencyCapKey as FrequencyCapKey,
)
from google.ads.googleads.v8.common.types.keyword_plan_common import (
    ConceptGroup as ConceptGroup,
    HistoricalMetricsOptions as HistoricalMetricsOptions,
    KeywordAnnotations as KeywordAnnotations,
    KeywordConcept as KeywordConcept,
    KeywordPlanAggregateMetricResults as KeywordPlanAggregateMetricResults,
    KeywordPlanAggregateMetrics as KeywordPlanAggregateMetrics,
    KeywordPlanDeviceSearches as KeywordPlanDeviceSearches,
    KeywordPlanHistoricalMetrics as KeywordPlanHistoricalMetrics,
    MonthlySearchVolume as MonthlySearchVolume,
)
from google.ads.googleads.v8.common.types.matching_function import (
    MatchingFunction as MatchingFunction,
    Operand as Operand,
)
from google.ads.googleads.v8.common.types.metrics import Metrics as Metrics
from google.ads.googleads.v8.common.types.offline_user_data import (
    CustomerMatchUserListMetadata as CustomerMatchUserListMetadata,
    ItemAttribute as ItemAttribute,
    OfflineUserAddressInfo as OfflineUserAddressInfo,
    StoreAttribute as StoreAttribute,
    StoreSalesMetadata as StoreSalesMetadata,
    StoreSalesThirdPartyMetadata as StoreSalesThirdPartyMetadata,
    TransactionAttribute as TransactionAttribute,
    UserAttribute as UserAttribute,
    UserData as UserData,
    UserIdentifier as UserIdentifier,
)
from google.ads.googleads.v8.common.types.policy import (
    PolicyTopicConstraint as PolicyTopicConstraint,
    PolicyTopicEntry as PolicyTopicEntry,
    PolicyTopicEvidence as PolicyTopicEvidence,
    PolicyValidationParameter as PolicyValidationParameter,
    PolicyViolationKey as PolicyViolationKey,
)
from google.ads.googleads.v8.common.types.real_time_bidding_setting import (
    RealTimeBiddingSetting as RealTimeBiddingSetting,
)
from google.ads.googleads.v8.common.types.segments import (
    AssetInteractionTarget as AssetInteractionTarget,
    BudgetCampaignAssociationStatus as BudgetCampaignAssociationStatus,
    Keyword as Keyword,
    Segments as Segments,
)
from google.ads.googleads.v8.common.types.simulation import (
    BidModifierSimulationPoint as BidModifierSimulationPoint,
    BidModifierSimulationPointList as BidModifierSimulationPointList,
    BudgetSimulationPoint as BudgetSimulationPoint,
    BudgetSimulationPointList as BudgetSimulationPointList,
    CpcBidSimulationPoint as CpcBidSimulationPoint,
    CpcBidSimulationPointList as CpcBidSimulationPointList,
    CpvBidSimulationPoint as CpvBidSimulationPoint,
    CpvBidSimulationPointList as CpvBidSimulationPointList,
    PercentCpcBidSimulationPoint as PercentCpcBidSimulationPoint,
    PercentCpcBidSimulationPointList as PercentCpcBidSimulationPointList,
    TargetCpaSimulationPoint as TargetCpaSimulationPoint,
    TargetCpaSimulationPointList as TargetCpaSimulationPointList,
    TargetImpressionShareSimulationPoint as TargetImpressionShareSimulationPoint,
    TargetImpressionShareSimulationPointList as TargetImpressionShareSimulationPointList,
    TargetRoasSimulationPoint as TargetRoasSimulationPoint,
    TargetRoasSimulationPointList as TargetRoasSimulationPointList,
)
from google.ads.googleads.v8.common.types.tag_snippet import TagSnippet as TagSnippet
from google.ads.googleads.v8.common.types.targeting_setting import (
    TargetingSetting as TargetingSetting,
    TargetRestriction as TargetRestriction,
    TargetRestrictionOperation as TargetRestrictionOperation,
)
from google.ads.googleads.v8.common.types.text_label import TextLabel as TextLabel
from google.ads.googleads.v8.common.types.url_collection import (
    UrlCollection as UrlCollection,
)
from google.ads.googleads.v8.common.types.user_lists import (
    BasicUserListInfo as BasicUserListInfo,
    CombinedRuleUserListInfo as CombinedRuleUserListInfo,
    CrmBasedUserListInfo as CrmBasedUserListInfo,
    DateSpecificRuleUserListInfo as DateSpecificRuleUserListInfo,
    ExpressionRuleUserListInfo as ExpressionRuleUserListInfo,
    LogicalUserListInfo as LogicalUserListInfo,
    LogicalUserListOperandInfo as LogicalUserListOperandInfo,
    RuleBasedUserListInfo as RuleBasedUserListInfo,
    SimilarUserListInfo as SimilarUserListInfo,
    UserListActionInfo as UserListActionInfo,
    UserListDateRuleItemInfo as UserListDateRuleItemInfo,
    UserListLogicalRuleInfo as UserListLogicalRuleInfo,
    UserListNumberRuleItemInfo as UserListNumberRuleItemInfo,
    UserListRuleInfo as UserListRuleInfo,
    UserListRuleItemGroupInfo as UserListRuleItemGroupInfo,
    UserListRuleItemInfo as UserListRuleItemInfo,
    UserListStringRuleItemInfo as UserListStringRuleItemInfo,
)
from google.ads.googleads.v8.common.types.value import Value as Value
from google.ads.googleads.v8.enums.types.access_invitation_status import (
    AccessInvitationStatusEnum as AccessInvitationStatusEnum,
)
from google.ads.googleads.v8.enums.types.access_reason import (
    AccessReasonEnum as AccessReasonEnum,
)
from google.ads.googleads.v8.enums.types.access_role import (
    AccessRoleEnum as AccessRoleEnum,
)
from google.ads.googleads.v8.enums.types.account_budget_proposal_status import (
    AccountBudgetProposalStatusEnum as AccountBudgetProposalStatusEnum,
)
from google.ads.googleads.v8.enums.types.account_budget_proposal_type import (
    AccountBudgetProposalTypeEnum as AccountBudgetProposalTypeEnum,
)
from google.ads.googleads.v8.enums.types.account_budget_status import (
    AccountBudgetStatusEnum as AccountBudgetStatusEnum,
)
from google.ads.googleads.v8.enums.types.account_link_status import (
    AccountLinkStatusEnum as AccountLinkStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_customizer_placeholder_field import (
    AdCustomizerPlaceholderFieldEnum as AdCustomizerPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.ad_destination_type import (
    AdDestinationTypeEnum as AdDestinationTypeEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_ad_rotation_mode import (
    AdGroupAdRotationModeEnum as AdGroupAdRotationModeEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_ad_status import (
    AdGroupAdStatusEnum as AdGroupAdStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_criterion_approval_status import (
    AdGroupCriterionApprovalStatusEnum as AdGroupCriterionApprovalStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_criterion_status import (
    AdGroupCriterionStatusEnum as AdGroupCriterionStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_status import (
    AdGroupStatusEnum as AdGroupStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_group_type import (
    AdGroupTypeEnum as AdGroupTypeEnum,
)
from google.ads.googleads.v8.enums.types.ad_network_type import (
    AdNetworkTypeEnum as AdNetworkTypeEnum,
)
from google.ads.googleads.v8.enums.types.ad_serving_optimization_status import (
    AdServingOptimizationStatusEnum as AdServingOptimizationStatusEnum,
)
from google.ads.googleads.v8.enums.types.ad_strength import (
    AdStrengthEnum as AdStrengthEnum,
)
from google.ads.googleads.v8.enums.types.ad_type import AdTypeEnum as AdTypeEnum
from google.ads.googleads.v8.enums.types.advertising_channel_sub_type import (
    AdvertisingChannelSubTypeEnum as AdvertisingChannelSubTypeEnum,
)
from google.ads.googleads.v8.enums.types.advertising_channel_type import (
    AdvertisingChannelTypeEnum as AdvertisingChannelTypeEnum,
)
from google.ads.googleads.v8.enums.types.affiliate_location_feed_relationship_type import (
    AffiliateLocationFeedRelationshipTypeEnum as AffiliateLocationFeedRelationshipTypeEnum,
)
from google.ads.googleads.v8.enums.types.affiliate_location_placeholder_field import (
    AffiliateLocationPlaceholderFieldEnum as AffiliateLocationPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.age_range_type import (
    AgeRangeTypeEnum as AgeRangeTypeEnum,
)
from google.ads.googleads.v8.enums.types.app_campaign_app_store import (
    AppCampaignAppStoreEnum as AppCampaignAppStoreEnum,
)
from google.ads.googleads.v8.enums.types.app_campaign_bidding_strategy_goal_type import (
    AppCampaignBiddingStrategyGoalTypeEnum as AppCampaignBiddingStrategyGoalTypeEnum,
)
from google.ads.googleads.v8.enums.types.app_payment_model_type import (
    AppPaymentModelTypeEnum as AppPaymentModelTypeEnum,
)
from google.ads.googleads.v8.enums.types.app_placeholder_field import (
    AppPlaceholderFieldEnum as AppPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.app_store import AppStoreEnum as AppStoreEnum
from google.ads.googleads.v8.enums.types.app_url_operating_system_type import (
    AppUrlOperatingSystemTypeEnum as AppUrlOperatingSystemTypeEnum,
)
from google.ads.googleads.v8.enums.types.asset_field_type import (
    AssetFieldTypeEnum as AssetFieldTypeEnum,
)
from google.ads.googleads.v8.enums.types.asset_link_status import (
    AssetLinkStatusEnum as AssetLinkStatusEnum,
)
from google.ads.googleads.v8.enums.types.asset_performance_label import (
    AssetPerformanceLabelEnum as AssetPerformanceLabelEnum,
)
from google.ads.googleads.v8.enums.types.asset_type import (
    AssetTypeEnum as AssetTypeEnum,
)
from google.ads.googleads.v8.enums.types.attribution_model import (
    AttributionModelEnum as AttributionModelEnum,
)
from google.ads.googleads.v8.enums.types.batch_job_status import (
    BatchJobStatusEnum as BatchJobStatusEnum,
)
from google.ads.googleads.v8.enums.types.bid_modifier_source import (
    BidModifierSourceEnum as BidModifierSourceEnum,
)
from google.ads.googleads.v8.enums.types.bidding_source import (
    BiddingSourceEnum as BiddingSourceEnum,
)
from google.ads.googleads.v8.enums.types.bidding_strategy_status import (
    BiddingStrategyStatusEnum as BiddingStrategyStatusEnum,
)
from google.ads.googleads.v8.enums.types.bidding_strategy_type import (
    BiddingStrategyTypeEnum as BiddingStrategyTypeEnum,
)
from google.ads.googleads.v8.enums.types.billing_setup_status import (
    BillingSetupStatusEnum as BillingSetupStatusEnum,
)
from google.ads.googleads.v8.enums.types.brand_safety_suitability import (
    BrandSafetySuitabilityEnum as BrandSafetySuitabilityEnum,
)
from google.ads.googleads.v8.enums.types.budget_campaign_association_status import (
    BudgetCampaignAssociationStatusEnum as BudgetCampaignAssociationStatusEnum,
)
from google.ads.googleads.v8.enums.types.budget_delivery_method import (
    BudgetDeliveryMethodEnum as BudgetDeliveryMethodEnum,
)
from google.ads.googleads.v8.enums.types.budget_period import (
    BudgetPeriodEnum as BudgetPeriodEnum,
)
from google.ads.googleads.v8.enums.types.budget_status import (
    BudgetStatusEnum as BudgetStatusEnum,
)
from google.ads.googleads.v8.enums.types.budget_type import (
    BudgetTypeEnum as BudgetTypeEnum,
)
from google.ads.googleads.v8.enums.types.call_conversion_reporting_state import (
    CallConversionReportingStateEnum as CallConversionReportingStateEnum,
)
from google.ads.googleads.v8.enums.types.call_placeholder_field import (
    CallPlaceholderFieldEnum as CallPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.call_tracking_display_location import (
    CallTrackingDisplayLocationEnum as CallTrackingDisplayLocationEnum,
)
from google.ads.googleads.v8.enums.types.call_type import CallTypeEnum as CallTypeEnum
from google.ads.googleads.v8.enums.types.callout_placeholder_field import (
    CalloutPlaceholderFieldEnum as CalloutPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.campaign_criterion_status import (
    CampaignCriterionStatusEnum as CampaignCriterionStatusEnum,
)
from google.ads.googleads.v8.enums.types.campaign_draft_status import (
    CampaignDraftStatusEnum as CampaignDraftStatusEnum,
)
from google.ads.googleads.v8.enums.types.campaign_experiment_status import (
    CampaignExperimentStatusEnum as CampaignExperimentStatusEnum,
)
from google.ads.googleads.v8.enums.types.campaign_experiment_traffic_split_type import (
    CampaignExperimentTrafficSplitTypeEnum as CampaignExperimentTrafficSplitTypeEnum,
)
from google.ads.googleads.v8.enums.types.campaign_experiment_type import (
    CampaignExperimentTypeEnum as CampaignExperimentTypeEnum,
)
from google.ads.googleads.v8.enums.types.campaign_serving_status import (
    CampaignServingStatusEnum as CampaignServingStatusEnum,
)
from google.ads.googleads.v8.enums.types.campaign_shared_set_status import (
    CampaignSharedSetStatusEnum as CampaignSharedSetStatusEnum,
)
from google.ads.googleads.v8.enums.types.campaign_status import (
    CampaignStatusEnum as CampaignStatusEnum,
)
from google.ads.googleads.v8.enums.types.change_client_type import (
    ChangeClientTypeEnum as ChangeClientTypeEnum,
)
from google.ads.googleads.v8.enums.types.change_event_resource_type import (
    ChangeEventResourceTypeEnum as ChangeEventResourceTypeEnum,
)
from google.ads.googleads.v8.enums.types.change_status_operation import (
    ChangeStatusOperationEnum as ChangeStatusOperationEnum,
)
from google.ads.googleads.v8.enums.types.change_status_resource_type import (
    ChangeStatusResourceTypeEnum as ChangeStatusResourceTypeEnum,
)
from google.ads.googleads.v8.enums.types.click_type import (
    ClickTypeEnum as ClickTypeEnum,
)
from google.ads.googleads.v8.enums.types.combined_audience_status import (
    CombinedAudienceStatusEnum as CombinedAudienceStatusEnum,
)
from google.ads.googleads.v8.enums.types.content_label_type import (
    ContentLabelTypeEnum as ContentLabelTypeEnum,
)
from google.ads.googleads.v8.enums.types.conversion_action_category import (
    ConversionActionCategoryEnum as ConversionActionCategoryEnum,
)
from google.ads.googleads.v8.enums.types.conversion_action_counting_type import (
    ConversionActionCountingTypeEnum as ConversionActionCountingTypeEnum,
)
from google.ads.googleads.v8.enums.types.conversion_action_status import (
    ConversionActionStatusEnum as ConversionActionStatusEnum,
)
from google.ads.googleads.v8.enums.types.conversion_action_type import (
    ConversionActionTypeEnum as ConversionActionTypeEnum,
)
from google.ads.googleads.v8.enums.types.conversion_adjustment_type import (
    ConversionAdjustmentTypeEnum as ConversionAdjustmentTypeEnum,
)
from google.ads.googleads.v8.enums.types.conversion_attribution_event_type import (
    ConversionAttributionEventTypeEnum as ConversionAttributionEventTypeEnum,
)
from google.ads.googleads.v8.enums.types.conversion_custom_variable_status import (
    ConversionCustomVariableStatusEnum as ConversionCustomVariableStatusEnum,
)
from google.ads.googleads.v8.enums.types.conversion_lag_bucket import (
    ConversionLagBucketEnum as ConversionLagBucketEnum,
)
from google.ads.googleads.v8.enums.types.conversion_or_adjustment_lag_bucket import (
    ConversionOrAdjustmentLagBucketEnum as ConversionOrAdjustmentLagBucketEnum,
)
from google.ads.googleads.v8.enums.types.conversion_value_rule_primary_dimension import (
    ConversionValueRulePrimaryDimensionEnum as ConversionValueRulePrimaryDimensionEnum,
)
from google.ads.googleads.v8.enums.types.conversion_value_rule_set_status import (
    ConversionValueRuleSetStatusEnum as ConversionValueRuleSetStatusEnum,
)
from google.ads.googleads.v8.enums.types.conversion_value_rule_status import (
    ConversionValueRuleStatusEnum as ConversionValueRuleStatusEnum,
)
from google.ads.googleads.v8.enums.types.criterion_category_channel_availability_mode import (
    CriterionCategoryChannelAvailabilityModeEnum as CriterionCategoryChannelAvailabilityModeEnum,
)
from google.ads.googleads.v8.enums.types.criterion_category_locale_availability_mode import (
    CriterionCategoryLocaleAvailabilityModeEnum as CriterionCategoryLocaleAvailabilityModeEnum,
)
from google.ads.googleads.v8.enums.types.criterion_system_serving_status import (
    CriterionSystemServingStatusEnum as CriterionSystemServingStatusEnum,
)
from google.ads.googleads.v8.enums.types.criterion_type import (
    CriterionTypeEnum as CriterionTypeEnum,
)
from google.ads.googleads.v8.enums.types.custom_audience_member_type import (
    CustomAudienceMemberTypeEnum as CustomAudienceMemberTypeEnum,
)
from google.ads.googleads.v8.enums.types.custom_audience_status import (
    CustomAudienceStatusEnum as CustomAudienceStatusEnum,
)
from google.ads.googleads.v8.enums.types.custom_audience_type import (
    CustomAudienceTypeEnum as CustomAudienceTypeEnum,
)
from google.ads.googleads.v8.enums.types.custom_interest_member_type import (
    CustomInterestMemberTypeEnum as CustomInterestMemberTypeEnum,
)
from google.ads.googleads.v8.enums.types.custom_interest_status import (
    CustomInterestStatusEnum as CustomInterestStatusEnum,
)
from google.ads.googleads.v8.enums.types.custom_interest_type import (
    CustomInterestTypeEnum as CustomInterestTypeEnum,
)
from google.ads.googleads.v8.enums.types.custom_placeholder_field import (
    CustomPlaceholderFieldEnum as CustomPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.customer_match_upload_key_type import (
    CustomerMatchUploadKeyTypeEnum as CustomerMatchUploadKeyTypeEnum,
)
from google.ads.googleads.v8.enums.types.customer_pay_per_conversion_eligibility_failure_reason import (
    CustomerPayPerConversionEligibilityFailureReasonEnum as CustomerPayPerConversionEligibilityFailureReasonEnum,
)
from google.ads.googleads.v8.enums.types.data_driven_model_status import (
    DataDrivenModelStatusEnum as DataDrivenModelStatusEnum,
)
from google.ads.googleads.v8.enums.types.day_of_week import (
    DayOfWeekEnum as DayOfWeekEnum,
)
from google.ads.googleads.v8.enums.types.device import DeviceEnum as DeviceEnum
from google.ads.googleads.v8.enums.types.display_ad_format_setting import (
    DisplayAdFormatSettingEnum as DisplayAdFormatSettingEnum,
)
from google.ads.googleads.v8.enums.types.display_upload_product_type import (
    DisplayUploadProductTypeEnum as DisplayUploadProductTypeEnum,
)
from google.ads.googleads.v8.enums.types.distance_bucket import (
    DistanceBucketEnum as DistanceBucketEnum,
)
from google.ads.googleads.v8.enums.types.dsa_page_feed_criterion_field import (
    DsaPageFeedCriterionFieldEnum as DsaPageFeedCriterionFieldEnum,
)
from google.ads.googleads.v8.enums.types.education_placeholder_field import (
    EducationPlaceholderFieldEnum as EducationPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.extension_setting_device import (
    ExtensionSettingDeviceEnum as ExtensionSettingDeviceEnum,
)
from google.ads.googleads.v8.enums.types.extension_type import (
    ExtensionTypeEnum as ExtensionTypeEnum,
)
from google.ads.googleads.v8.enums.types.external_conversion_source import (
    ExternalConversionSourceEnum as ExternalConversionSourceEnum,
)
from google.ads.googleads.v8.enums.types.feed_attribute_type import (
    FeedAttributeTypeEnum as FeedAttributeTypeEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_quality_approval_status import (
    FeedItemQualityApprovalStatusEnum as FeedItemQualityApprovalStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_quality_disapproval_reason import (
    FeedItemQualityDisapprovalReasonEnum as FeedItemQualityDisapprovalReasonEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_set_status import (
    FeedItemSetStatusEnum as FeedItemSetStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_set_string_filter_type import (
    FeedItemSetStringFilterTypeEnum as FeedItemSetStringFilterTypeEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_status import (
    FeedItemStatusEnum as FeedItemStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_target_device import (
    FeedItemTargetDeviceEnum as FeedItemTargetDeviceEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_target_status import (
    FeedItemTargetStatusEnum as FeedItemTargetStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_target_type import (
    FeedItemTargetTypeEnum as FeedItemTargetTypeEnum,
)
from google.ads.googleads.v8.enums.types.feed_item_validation_status import (
    FeedItemValidationStatusEnum as FeedItemValidationStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_link_status import (
    FeedLinkStatusEnum as FeedLinkStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_mapping_criterion_type import (
    FeedMappingCriterionTypeEnum as FeedMappingCriterionTypeEnum,
)
from google.ads.googleads.v8.enums.types.feed_mapping_status import (
    FeedMappingStatusEnum as FeedMappingStatusEnum,
)
from google.ads.googleads.v8.enums.types.feed_origin import (
    FeedOriginEnum as FeedOriginEnum,
)
from google.ads.googleads.v8.enums.types.feed_status import (
    FeedStatusEnum as FeedStatusEnum,
)
from google.ads.googleads.v8.enums.types.flight_placeholder_field import (
    FlightPlaceholderFieldEnum as FlightPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.frequency_cap_event_type import (
    FrequencyCapEventTypeEnum as FrequencyCapEventTypeEnum,
)
from google.ads.googleads.v8.enums.types.frequency_cap_level import (
    FrequencyCapLevelEnum as FrequencyCapLevelEnum,
)
from google.ads.googleads.v8.enums.types.frequency_cap_time_unit import (
    FrequencyCapTimeUnitEnum as FrequencyCapTimeUnitEnum,
)
from google.ads.googleads.v8.enums.types.gender_type import (
    GenderTypeEnum as GenderTypeEnum,
)
from google.ads.googleads.v8.enums.types.geo_target_constant_status import (
    GeoTargetConstantStatusEnum as GeoTargetConstantStatusEnum,
)
from google.ads.googleads.v8.enums.types.geo_targeting_restriction import (
    GeoTargetingRestrictionEnum as GeoTargetingRestrictionEnum,
)
from google.ads.googleads.v8.enums.types.geo_targeting_type import (
    GeoTargetingTypeEnum as GeoTargetingTypeEnum,
)
from google.ads.googleads.v8.enums.types.google_ads_field_category import (
    GoogleAdsFieldCategoryEnum as GoogleAdsFieldCategoryEnum,
)
from google.ads.googleads.v8.enums.types.google_ads_field_data_type import (
    GoogleAdsFieldDataTypeEnum as GoogleAdsFieldDataTypeEnum,
)
from google.ads.googleads.v8.enums.types.google_voice_call_status import (
    GoogleVoiceCallStatusEnum as GoogleVoiceCallStatusEnum,
)
from google.ads.googleads.v8.enums.types.hotel_date_selection_type import (
    HotelDateSelectionTypeEnum as HotelDateSelectionTypeEnum,
)
from google.ads.googleads.v8.enums.types.hotel_placeholder_field import (
    HotelPlaceholderFieldEnum as HotelPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.hotel_price_bucket import (
    HotelPriceBucketEnum as HotelPriceBucketEnum,
)
from google.ads.googleads.v8.enums.types.hotel_rate_type import (
    HotelRateTypeEnum as HotelRateTypeEnum,
)
from google.ads.googleads.v8.enums.types.image_placeholder_field import (
    ImagePlaceholderFieldEnum as ImagePlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.income_range_type import (
    IncomeRangeTypeEnum as IncomeRangeTypeEnum,
)
from google.ads.googleads.v8.enums.types.interaction_event_type import (
    InteractionEventTypeEnum as InteractionEventTypeEnum,
)
from google.ads.googleads.v8.enums.types.interaction_type import (
    InteractionTypeEnum as InteractionTypeEnum,
)
from google.ads.googleads.v8.enums.types.invoice_type import (
    InvoiceTypeEnum as InvoiceTypeEnum,
)
from google.ads.googleads.v8.enums.types.job_placeholder_field import (
    JobPlaceholderFieldEnum as JobPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.keyword_match_type import (
    KeywordMatchTypeEnum as KeywordMatchTypeEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_aggregate_metric_type import (
    KeywordPlanAggregateMetricTypeEnum as KeywordPlanAggregateMetricTypeEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_competition_level import (
    KeywordPlanCompetitionLevelEnum as KeywordPlanCompetitionLevelEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_concept_group_type import (
    KeywordPlanConceptGroupTypeEnum as KeywordPlanConceptGroupTypeEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_forecast_interval import (
    KeywordPlanForecastIntervalEnum as KeywordPlanForecastIntervalEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_keyword_annotation import (
    KeywordPlanKeywordAnnotationEnum as KeywordPlanKeywordAnnotationEnum,
)
from google.ads.googleads.v8.enums.types.keyword_plan_network import (
    KeywordPlanNetworkEnum as KeywordPlanNetworkEnum,
)
from google.ads.googleads.v8.enums.types.label_status import (
    LabelStatusEnum as LabelStatusEnum,
)
from google.ads.googleads.v8.enums.types.lead_form_call_to_action_type import (
    LeadFormCallToActionTypeEnum as LeadFormCallToActionTypeEnum,
)
from google.ads.googleads.v8.enums.types.lead_form_desired_intent import (
    LeadFormDesiredIntentEnum as LeadFormDesiredIntentEnum,
)
from google.ads.googleads.v8.enums.types.lead_form_field_user_input_type import (
    LeadFormFieldUserInputTypeEnum as LeadFormFieldUserInputTypeEnum,
)
from google.ads.googleads.v8.enums.types.lead_form_post_submit_call_to_action_type import (
    LeadFormPostSubmitCallToActionTypeEnum as LeadFormPostSubmitCallToActionTypeEnum,
)
from google.ads.googleads.v8.enums.types.legacy_app_install_ad_app_store import (
    LegacyAppInstallAdAppStoreEnum as LegacyAppInstallAdAppStoreEnum,
)
from google.ads.googleads.v8.enums.types.linked_account_type import (
    LinkedAccountTypeEnum as LinkedAccountTypeEnum,
)
from google.ads.googleads.v8.enums.types.listing_group_type import (
    ListingGroupTypeEnum as ListingGroupTypeEnum,
)
from google.ads.googleads.v8.enums.types.local_placeholder_field import (
    LocalPlaceholderFieldEnum as LocalPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.location_extension_targeting_criterion_field import (
    LocationExtensionTargetingCriterionFieldEnum as LocationExtensionTargetingCriterionFieldEnum,
)
from google.ads.googleads.v8.enums.types.location_group_radius_units import (
    LocationGroupRadiusUnitsEnum as LocationGroupRadiusUnitsEnum,
)
from google.ads.googleads.v8.enums.types.location_placeholder_field import (
    LocationPlaceholderFieldEnum as LocationPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.location_source_type import (
    LocationSourceTypeEnum as LocationSourceTypeEnum,
)
from google.ads.googleads.v8.enums.types.manager_link_status import (
    ManagerLinkStatusEnum as ManagerLinkStatusEnum,
)
from google.ads.googleads.v8.enums.types.matching_function_context_type import (
    MatchingFunctionContextTypeEnum as MatchingFunctionContextTypeEnum,
)
from google.ads.googleads.v8.enums.types.matching_function_operator import (
    MatchingFunctionOperatorEnum as MatchingFunctionOperatorEnum,
)
from google.ads.googleads.v8.enums.types.media_type import (
    MediaTypeEnum as MediaTypeEnum,
)
from google.ads.googleads.v8.enums.types.merchant_center_link_status import (
    MerchantCenterLinkStatusEnum as MerchantCenterLinkStatusEnum,
)
from google.ads.googleads.v8.enums.types.message_placeholder_field import (
    MessagePlaceholderFieldEnum as MessagePlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.mime_type import MimeTypeEnum as MimeTypeEnum
from google.ads.googleads.v8.enums.types.minute_of_hour import (
    MinuteOfHourEnum as MinuteOfHourEnum,
)
from google.ads.googleads.v8.enums.types.mobile_app_vendor import (
    MobileAppVendorEnum as MobileAppVendorEnum,
)
from google.ads.googleads.v8.enums.types.mobile_device_type import (
    MobileDeviceTypeEnum as MobileDeviceTypeEnum,
)
from google.ads.googleads.v8.enums.types.month_of_year import (
    MonthOfYearEnum as MonthOfYearEnum,
)
from google.ads.googleads.v8.enums.types.negative_geo_target_type import (
    NegativeGeoTargetTypeEnum as NegativeGeoTargetTypeEnum,
)
from google.ads.googleads.v8.enums.types.offline_user_data_job_failure_reason import (
    OfflineUserDataJobFailureReasonEnum as OfflineUserDataJobFailureReasonEnum,
)
from google.ads.googleads.v8.enums.types.offline_user_data_job_status import (
    OfflineUserDataJobStatusEnum as OfflineUserDataJobStatusEnum,
)
from google.ads.googleads.v8.enums.types.offline_user_data_job_type import (
    OfflineUserDataJobTypeEnum as OfflineUserDataJobTypeEnum,
)
from google.ads.googleads.v8.enums.types.operating_system_version_operator_type import (
    OperatingSystemVersionOperatorTypeEnum as OperatingSystemVersionOperatorTypeEnum,
)
from google.ads.googleads.v8.enums.types.optimization_goal_type import (
    OptimizationGoalTypeEnum as OptimizationGoalTypeEnum,
)
from google.ads.googleads.v8.enums.types.parental_status_type import (
    ParentalStatusTypeEnum as ParentalStatusTypeEnum,
)
from google.ads.googleads.v8.enums.types.payment_mode import (
    PaymentModeEnum as PaymentModeEnum,
)
from google.ads.googleads.v8.enums.types.placeholder_type import (
    PlaceholderTypeEnum as PlaceholderTypeEnum,
)
from google.ads.googleads.v8.enums.types.placement_type import (
    PlacementTypeEnum as PlacementTypeEnum,
)
from google.ads.googleads.v8.enums.types.policy_approval_status import (
    PolicyApprovalStatusEnum as PolicyApprovalStatusEnum,
)
from google.ads.googleads.v8.enums.types.policy_review_status import (
    PolicyReviewStatusEnum as PolicyReviewStatusEnum,
)
from google.ads.googleads.v8.enums.types.policy_topic_entry_type import (
    PolicyTopicEntryTypeEnum as PolicyTopicEntryTypeEnum,
)
from google.ads.googleads.v8.enums.types.policy_topic_evidence_destination_mismatch_url_type import (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum as PolicyTopicEvidenceDestinationMismatchUrlTypeEnum,
)
from google.ads.googleads.v8.enums.types.policy_topic_evidence_destination_not_working_device import (
    PolicyTopicEvidenceDestinationNotWorkingDeviceEnum as PolicyTopicEvidenceDestinationNotWorkingDeviceEnum,
)
from google.ads.googleads.v8.enums.types.policy_topic_evidence_destination_not_working_dns_error_type import (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum as PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum,
)
from google.ads.googleads.v8.enums.types.positive_geo_target_type import (
    PositiveGeoTargetTypeEnum as PositiveGeoTargetTypeEnum,
)
from google.ads.googleads.v8.enums.types.preferred_content_type import (
    PreferredContentTypeEnum as PreferredContentTypeEnum,
)
from google.ads.googleads.v8.enums.types.price_extension_price_qualifier import (
    PriceExtensionPriceQualifierEnum as PriceExtensionPriceQualifierEnum,
)
from google.ads.googleads.v8.enums.types.price_extension_price_unit import (
    PriceExtensionPriceUnitEnum as PriceExtensionPriceUnitEnum,
)
from google.ads.googleads.v8.enums.types.price_extension_type import (
    PriceExtensionTypeEnum as PriceExtensionTypeEnum,
)
from google.ads.googleads.v8.enums.types.price_placeholder_field import (
    PricePlaceholderFieldEnum as PricePlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.product_bidding_category_level import (
    ProductBiddingCategoryLevelEnum as ProductBiddingCategoryLevelEnum,
)
from google.ads.googleads.v8.enums.types.product_bidding_category_status import (
    ProductBiddingCategoryStatusEnum as ProductBiddingCategoryStatusEnum,
)
from google.ads.googleads.v8.enums.types.product_channel import (
    ProductChannelEnum as ProductChannelEnum,
)
from google.ads.googleads.v8.enums.types.product_channel_exclusivity import (
    ProductChannelExclusivityEnum as ProductChannelExclusivityEnum,
)
from google.ads.googleads.v8.enums.types.product_condition import (
    ProductConditionEnum as ProductConditionEnum,
)
from google.ads.googleads.v8.enums.types.product_custom_attribute_index import (
    ProductCustomAttributeIndexEnum as ProductCustomAttributeIndexEnum,
)
from google.ads.googleads.v8.enums.types.product_type_level import (
    ProductTypeLevelEnum as ProductTypeLevelEnum,
)
from google.ads.googleads.v8.enums.types.promotion_extension_discount_modifier import (
    PromotionExtensionDiscountModifierEnum as PromotionExtensionDiscountModifierEnum,
)
from google.ads.googleads.v8.enums.types.promotion_extension_occasion import (
    PromotionExtensionOccasionEnum as PromotionExtensionOccasionEnum,
)
from google.ads.googleads.v8.enums.types.promotion_placeholder_field import (
    PromotionPlaceholderFieldEnum as PromotionPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.proximity_radius_units import (
    ProximityRadiusUnitsEnum as ProximityRadiusUnitsEnum,
)
from google.ads.googleads.v8.enums.types.quality_score_bucket import (
    QualityScoreBucketEnum as QualityScoreBucketEnum,
)
from google.ads.googleads.v8.enums.types.reach_plan_ad_length import (
    ReachPlanAdLengthEnum as ReachPlanAdLengthEnum,
)
from google.ads.googleads.v8.enums.types.reach_plan_age_range import (
    ReachPlanAgeRangeEnum as ReachPlanAgeRangeEnum,
)
from google.ads.googleads.v8.enums.types.reach_plan_network import (
    ReachPlanNetworkEnum as ReachPlanNetworkEnum,
)
from google.ads.googleads.v8.enums.types.real_estate_placeholder_field import (
    RealEstatePlaceholderFieldEnum as RealEstatePlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.recommendation_type import (
    RecommendationTypeEnum as RecommendationTypeEnum,
)
from google.ads.googleads.v8.enums.types.resource_change_operation import (
    ResourceChangeOperationEnum as ResourceChangeOperationEnum,
)
from google.ads.googleads.v8.enums.types.resource_limit_type import (
    ResourceLimitTypeEnum as ResourceLimitTypeEnum,
)
from google.ads.googleads.v8.enums.types.response_content_type import (
    ResponseContentTypeEnum as ResponseContentTypeEnum,
)
from google.ads.googleads.v8.enums.types.search_engine_results_page_type import (
    SearchEngineResultsPageTypeEnum as SearchEngineResultsPageTypeEnum,
)
from google.ads.googleads.v8.enums.types.search_term_match_type import (
    SearchTermMatchTypeEnum as SearchTermMatchTypeEnum,
)
from google.ads.googleads.v8.enums.types.search_term_targeting_status import (
    SearchTermTargetingStatusEnum as SearchTermTargetingStatusEnum,
)
from google.ads.googleads.v8.enums.types.seasonality_event_scope import (
    SeasonalityEventScopeEnum as SeasonalityEventScopeEnum,
)
from google.ads.googleads.v8.enums.types.seasonality_event_status import (
    SeasonalityEventStatusEnum as SeasonalityEventStatusEnum,
)
from google.ads.googleads.v8.enums.types.served_asset_field_type import (
    ServedAssetFieldTypeEnum as ServedAssetFieldTypeEnum,
)
from google.ads.googleads.v8.enums.types.shared_set_status import (
    SharedSetStatusEnum as SharedSetStatusEnum,
)
from google.ads.googleads.v8.enums.types.shared_set_type import (
    SharedSetTypeEnum as SharedSetTypeEnum,
)
from google.ads.googleads.v8.enums.types.simulation_modification_method import (
    SimulationModificationMethodEnum as SimulationModificationMethodEnum,
)
from google.ads.googleads.v8.enums.types.simulation_type import (
    SimulationTypeEnum as SimulationTypeEnum,
)
from google.ads.googleads.v8.enums.types.sitelink_placeholder_field import (
    SitelinkPlaceholderFieldEnum as SitelinkPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.slot import SlotEnum as SlotEnum
from google.ads.googleads.v8.enums.types.spending_limit_type import (
    SpendingLimitTypeEnum as SpendingLimitTypeEnum,
)
from google.ads.googleads.v8.enums.types.structured_snippet_placeholder_field import (
    StructuredSnippetPlaceholderFieldEnum as StructuredSnippetPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.summary_row_setting import (
    SummaryRowSettingEnum as SummaryRowSettingEnum,
)
from google.ads.googleads.v8.enums.types.system_managed_entity_source import (
    SystemManagedResourceSourceEnum as SystemManagedResourceSourceEnum,
)
from google.ads.googleads.v8.enums.types.target_cpa_opt_in_recommendation_goal import (
    TargetCpaOptInRecommendationGoalEnum as TargetCpaOptInRecommendationGoalEnum,
)
from google.ads.googleads.v8.enums.types.target_impression_share_location import (
    TargetImpressionShareLocationEnum as TargetImpressionShareLocationEnum,
)
from google.ads.googleads.v8.enums.types.targeting_dimension import (
    TargetingDimensionEnum as TargetingDimensionEnum,
)
from google.ads.googleads.v8.enums.types.time_type import TimeTypeEnum as TimeTypeEnum
from google.ads.googleads.v8.enums.types.tracking_code_page_format import (
    TrackingCodePageFormatEnum as TrackingCodePageFormatEnum,
)
from google.ads.googleads.v8.enums.types.tracking_code_type import (
    TrackingCodeTypeEnum as TrackingCodeTypeEnum,
)
from google.ads.googleads.v8.enums.types.travel_placeholder_field import (
    TravelPlaceholderFieldEnum as TravelPlaceholderFieldEnum,
)
from google.ads.googleads.v8.enums.types.user_identifier_source import (
    UserIdentifierSourceEnum as UserIdentifierSourceEnum,
)
from google.ads.googleads.v8.enums.types.user_interest_taxonomy_type import (
    UserInterestTaxonomyTypeEnum as UserInterestTaxonomyTypeEnum,
)
from google.ads.googleads.v8.enums.types.user_list_access_status import (
    UserListAccessStatusEnum as UserListAccessStatusEnum,
)
from google.ads.googleads.v8.enums.types.user_list_closing_reason import (
    UserListClosingReasonEnum as UserListClosingReasonEnum,
)
from google.ads.googleads.v8.enums.types.user_list_combined_rule_operator import (
    UserListCombinedRuleOperatorEnum as UserListCombinedRuleOperatorEnum,
)
from google.ads.googleads.v8.enums.types.user_list_crm_data_source_type import (
    UserListCrmDataSourceTypeEnum as UserListCrmDataSourceTypeEnum,
)
from google.ads.googleads.v8.enums.types.user_list_date_rule_item_operator import (
    UserListDateRuleItemOperatorEnum as UserListDateRuleItemOperatorEnum,
)
from google.ads.googleads.v8.enums.types.user_list_logical_rule_operator import (
    UserListLogicalRuleOperatorEnum as UserListLogicalRuleOperatorEnum,
)
from google.ads.googleads.v8.enums.types.user_list_membership_status import (
    UserListMembershipStatusEnum as UserListMembershipStatusEnum,
)
from google.ads.googleads.v8.enums.types.user_list_number_rule_item_operator import (
    UserListNumberRuleItemOperatorEnum as UserListNumberRuleItemOperatorEnum,
)
from google.ads.googleads.v8.enums.types.user_list_prepopulation_status import (
    UserListPrepopulationStatusEnum as UserListPrepopulationStatusEnum,
)
from google.ads.googleads.v8.enums.types.user_list_rule_type import (
    UserListRuleTypeEnum as UserListRuleTypeEnum,
)
from google.ads.googleads.v8.enums.types.user_list_size_range import (
    UserListSizeRangeEnum as UserListSizeRangeEnum,
)
from google.ads.googleads.v8.enums.types.user_list_string_rule_item_operator import (
    UserListStringRuleItemOperatorEnum as UserListStringRuleItemOperatorEnum,
)
from google.ads.googleads.v8.enums.types.user_list_type import (
    UserListTypeEnum as UserListTypeEnum,
)
from google.ads.googleads.v8.enums.types.value_rule_device_type import (
    ValueRuleDeviceTypeEnum as ValueRuleDeviceTypeEnum,
)
from google.ads.googleads.v8.enums.types.value_rule_geo_location_match_type import (
    ValueRuleGeoLocationMatchTypeEnum as ValueRuleGeoLocationMatchTypeEnum,
)
from google.ads.googleads.v8.enums.types.value_rule_operation import (
    ValueRuleOperationEnum as ValueRuleOperationEnum,
)
from google.ads.googleads.v8.enums.types.value_rule_set_attachment_type import (
    ValueRuleSetAttachmentTypeEnum as ValueRuleSetAttachmentTypeEnum,
)
from google.ads.googleads.v8.enums.types.value_rule_set_dimension import (
    ValueRuleSetDimensionEnum as ValueRuleSetDimensionEnum,
)
from google.ads.googleads.v8.enums.types.vanity_pharma_display_url_mode import (
    VanityPharmaDisplayUrlModeEnum as VanityPharmaDisplayUrlModeEnum,
)
from google.ads.googleads.v8.enums.types.vanity_pharma_text import (
    VanityPharmaTextEnum as VanityPharmaTextEnum,
)
from google.ads.googleads.v8.enums.types.webpage_condition_operand import (
    WebpageConditionOperandEnum as WebpageConditionOperandEnum,
)
from google.ads.googleads.v8.enums.types.webpage_condition_operator import (
    WebpageConditionOperatorEnum as WebpageConditionOperatorEnum,
)
from google.ads.googleads.v8.errors.types.access_invitation_error import (
    AccessInvitationErrorEnum as AccessInvitationErrorEnum,
)
from google.ads.googleads.v8.errors.types.account_budget_proposal_error import (
    AccountBudgetProposalErrorEnum as AccountBudgetProposalErrorEnum,
)
from google.ads.googleads.v8.errors.types.account_link_error import (
    AccountLinkErrorEnum as AccountLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_customizer_error import (
    AdCustomizerErrorEnum as AdCustomizerErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_error import AdErrorEnum as AdErrorEnum
from google.ads.googleads.v8.errors.types.ad_group_ad_error import (
    AdGroupAdErrorEnum as AdGroupAdErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_group_bid_modifier_error import (
    AdGroupBidModifierErrorEnum as AdGroupBidModifierErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_group_criterion_error import (
    AdGroupCriterionErrorEnum as AdGroupCriterionErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_group_error import (
    AdGroupErrorEnum as AdGroupErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_group_feed_error import (
    AdGroupFeedErrorEnum as AdGroupFeedErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_parameter_error import (
    AdParameterErrorEnum as AdParameterErrorEnum,
)
from google.ads.googleads.v8.errors.types.ad_sharing_error import (
    AdSharingErrorEnum as AdSharingErrorEnum,
)
from google.ads.googleads.v8.errors.types.adx_error import AdxErrorEnum as AdxErrorEnum
from google.ads.googleads.v8.errors.types.asset_error import (
    AssetErrorEnum as AssetErrorEnum,
)
from google.ads.googleads.v8.errors.types.asset_link_error import (
    AssetLinkErrorEnum as AssetLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.authentication_error import (
    AuthenticationErrorEnum as AuthenticationErrorEnum,
)
from google.ads.googleads.v8.errors.types.authorization_error import (
    AuthorizationErrorEnum as AuthorizationErrorEnum,
)
from google.ads.googleads.v8.errors.types.batch_job_error import (
    BatchJobErrorEnum as BatchJobErrorEnum,
)
from google.ads.googleads.v8.errors.types.bidding_error import (
    BiddingErrorEnum as BiddingErrorEnum,
)
from google.ads.googleads.v8.errors.types.bidding_strategy_error import (
    BiddingStrategyErrorEnum as BiddingStrategyErrorEnum,
)
from google.ads.googleads.v8.errors.types.billing_setup_error import (
    BillingSetupErrorEnum as BillingSetupErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_budget_error import (
    CampaignBudgetErrorEnum as CampaignBudgetErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_criterion_error import (
    CampaignCriterionErrorEnum as CampaignCriterionErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_draft_error import (
    CampaignDraftErrorEnum as CampaignDraftErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_error import (
    CampaignErrorEnum as CampaignErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_experiment_error import (
    CampaignExperimentErrorEnum as CampaignExperimentErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_feed_error import (
    CampaignFeedErrorEnum as CampaignFeedErrorEnum,
)
from google.ads.googleads.v8.errors.types.campaign_shared_set_error import (
    CampaignSharedSetErrorEnum as CampaignSharedSetErrorEnum,
)
from google.ads.googleads.v8.errors.types.change_event_error import (
    ChangeEventErrorEnum as ChangeEventErrorEnum,
)
from google.ads.googleads.v8.errors.types.change_status_error import (
    ChangeStatusErrorEnum as ChangeStatusErrorEnum,
)
from google.ads.googleads.v8.errors.types.collection_size_error import (
    CollectionSizeErrorEnum as CollectionSizeErrorEnum,
)
from google.ads.googleads.v8.errors.types.context_error import (
    ContextErrorEnum as ContextErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_action_error import (
    ConversionActionErrorEnum as ConversionActionErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_adjustment_upload_error import (
    ConversionAdjustmentUploadErrorEnum as ConversionAdjustmentUploadErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_custom_variable_error import (
    ConversionCustomVariableErrorEnum as ConversionCustomVariableErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_upload_error import (
    ConversionUploadErrorEnum as ConversionUploadErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_value_rule_error import (
    ConversionValueRuleErrorEnum as ConversionValueRuleErrorEnum,
)
from google.ads.googleads.v8.errors.types.conversion_value_rule_set_error import (
    ConversionValueRuleSetErrorEnum as ConversionValueRuleSetErrorEnum,
)
from google.ads.googleads.v8.errors.types.country_code_error import (
    CountryCodeErrorEnum as CountryCodeErrorEnum,
)
from google.ads.googleads.v8.errors.types.criterion_error import (
    CriterionErrorEnum as CriterionErrorEnum,
)
from google.ads.googleads.v8.errors.types.currency_code_error import (
    CurrencyCodeErrorEnum as CurrencyCodeErrorEnum,
)
from google.ads.googleads.v8.errors.types.custom_audience_error import (
    CustomAudienceErrorEnum as CustomAudienceErrorEnum,
)
from google.ads.googleads.v8.errors.types.custom_interest_error import (
    CustomInterestErrorEnum as CustomInterestErrorEnum,
)
from google.ads.googleads.v8.errors.types.customer_client_link_error import (
    CustomerClientLinkErrorEnum as CustomerClientLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.customer_error import (
    CustomerErrorEnum as CustomerErrorEnum,
)
from google.ads.googleads.v8.errors.types.customer_feed_error import (
    CustomerFeedErrorEnum as CustomerFeedErrorEnum,
)
from google.ads.googleads.v8.errors.types.customer_manager_link_error import (
    CustomerManagerLinkErrorEnum as CustomerManagerLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.customer_user_access_error import (
    CustomerUserAccessErrorEnum as CustomerUserAccessErrorEnum,
)
from google.ads.googleads.v8.errors.types.database_error import (
    DatabaseErrorEnum as DatabaseErrorEnum,
)
from google.ads.googleads.v8.errors.types.date_error import (
    DateErrorEnum as DateErrorEnum,
)
from google.ads.googleads.v8.errors.types.date_range_error import (
    DateRangeErrorEnum as DateRangeErrorEnum,
)
from google.ads.googleads.v8.errors.types.distinct_error import (
    DistinctErrorEnum as DistinctErrorEnum,
)
from google.ads.googleads.v8.errors.types.enum_error import (
    EnumErrorEnum as EnumErrorEnum,
)
from google.ads.googleads.v8.errors.types.errors import (
    ErrorCode as ErrorCode,
    ErrorDetails as ErrorDetails,
    ErrorLocation as ErrorLocation,
    GoogleAdsError as GoogleAdsError,
    GoogleAdsFailure as GoogleAdsFailure,
    PolicyFindingDetails as PolicyFindingDetails,
    PolicyViolationDetails as PolicyViolationDetails,
    QuotaErrorDetails as QuotaErrorDetails,
    ResourceCountDetails as ResourceCountDetails,
)
from google.ads.googleads.v8.errors.types.extension_feed_item_error import (
    ExtensionFeedItemErrorEnum as ExtensionFeedItemErrorEnum,
)
from google.ads.googleads.v8.errors.types.extension_setting_error import (
    ExtensionSettingErrorEnum as ExtensionSettingErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_attribute_reference_error import (
    FeedAttributeReferenceErrorEnum as FeedAttributeReferenceErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_error import (
    FeedErrorEnum as FeedErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_item_error import (
    FeedItemErrorEnum as FeedItemErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_item_set_error import (
    FeedItemSetErrorEnum as FeedItemSetErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_item_set_link_error import (
    FeedItemSetLinkErrorEnum as FeedItemSetLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_item_target_error import (
    FeedItemTargetErrorEnum as FeedItemTargetErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_item_validation_error import (
    FeedItemValidationErrorEnum as FeedItemValidationErrorEnum,
)
from google.ads.googleads.v8.errors.types.feed_mapping_error import (
    FeedMappingErrorEnum as FeedMappingErrorEnum,
)
from google.ads.googleads.v8.errors.types.field_error import (
    FieldErrorEnum as FieldErrorEnum,
)
from google.ads.googleads.v8.errors.types.field_mask_error import (
    FieldMaskErrorEnum as FieldMaskErrorEnum,
)
from google.ads.googleads.v8.errors.types.function_error import (
    FunctionErrorEnum as FunctionErrorEnum,
)
from google.ads.googleads.v8.errors.types.function_parsing_error import (
    FunctionParsingErrorEnum as FunctionParsingErrorEnum,
)
from google.ads.googleads.v8.errors.types.geo_target_constant_suggestion_error import (
    GeoTargetConstantSuggestionErrorEnum as GeoTargetConstantSuggestionErrorEnum,
)
from google.ads.googleads.v8.errors.types.header_error import (
    HeaderErrorEnum as HeaderErrorEnum,
)
from google.ads.googleads.v8.errors.types.id_error import IdErrorEnum as IdErrorEnum
from google.ads.googleads.v8.errors.types.image_error import (
    ImageErrorEnum as ImageErrorEnum,
)
from google.ads.googleads.v8.errors.types.internal_error import (
    InternalErrorEnum as InternalErrorEnum,
)
from google.ads.googleads.v8.errors.types.invoice_error import (
    InvoiceErrorEnum as InvoiceErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_ad_group_error import (
    KeywordPlanAdGroupErrorEnum as KeywordPlanAdGroupErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_ad_group_keyword_error import (
    KeywordPlanAdGroupKeywordErrorEnum as KeywordPlanAdGroupKeywordErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_campaign_error import (
    KeywordPlanCampaignErrorEnum as KeywordPlanCampaignErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_campaign_keyword_error import (
    KeywordPlanCampaignKeywordErrorEnum as KeywordPlanCampaignKeywordErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_error import (
    KeywordPlanErrorEnum as KeywordPlanErrorEnum,
)
from google.ads.googleads.v8.errors.types.keyword_plan_idea_error import (
    KeywordPlanIdeaErrorEnum as KeywordPlanIdeaErrorEnum,
)
from google.ads.googleads.v8.errors.types.label_error import (
    LabelErrorEnum as LabelErrorEnum,
)
from google.ads.googleads.v8.errors.types.language_code_error import (
    LanguageCodeErrorEnum as LanguageCodeErrorEnum,
)
from google.ads.googleads.v8.errors.types.list_operation_error import (
    ListOperationErrorEnum as ListOperationErrorEnum,
)
from google.ads.googleads.v8.errors.types.manager_link_error import (
    ManagerLinkErrorEnum as ManagerLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.media_bundle_error import (
    MediaBundleErrorEnum as MediaBundleErrorEnum,
)
from google.ads.googleads.v8.errors.types.media_file_error import (
    MediaFileErrorEnum as MediaFileErrorEnum,
)
from google.ads.googleads.v8.errors.types.media_upload_error import (
    MediaUploadErrorEnum as MediaUploadErrorEnum,
)
from google.ads.googleads.v8.errors.types.multiplier_error import (
    MultiplierErrorEnum as MultiplierErrorEnum,
)
from google.ads.googleads.v8.errors.types.mutate_error import (
    MutateErrorEnum as MutateErrorEnum,
)
from google.ads.googleads.v8.errors.types.new_resource_creation_error import (
    NewResourceCreationErrorEnum as NewResourceCreationErrorEnum,
)
from google.ads.googleads.v8.errors.types.not_allowlisted_error import (
    NotAllowlistedErrorEnum as NotAllowlistedErrorEnum,
)
from google.ads.googleads.v8.errors.types.not_empty_error import (
    NotEmptyErrorEnum as NotEmptyErrorEnum,
)
from google.ads.googleads.v8.errors.types.null_error import (
    NullErrorEnum as NullErrorEnum,
)
from google.ads.googleads.v8.errors.types.offline_user_data_job_error import (
    OfflineUserDataJobErrorEnum as OfflineUserDataJobErrorEnum,
)
from google.ads.googleads.v8.errors.types.operation_access_denied_error import (
    OperationAccessDeniedErrorEnum as OperationAccessDeniedErrorEnum,
)
from google.ads.googleads.v8.errors.types.operator_error import (
    OperatorErrorEnum as OperatorErrorEnum,
)
from google.ads.googleads.v8.errors.types.partial_failure_error import (
    PartialFailureErrorEnum as PartialFailureErrorEnum,
)
from google.ads.googleads.v8.errors.types.payments_account_error import (
    PaymentsAccountErrorEnum as PaymentsAccountErrorEnum,
)
from google.ads.googleads.v8.errors.types.policy_finding_error import (
    PolicyFindingErrorEnum as PolicyFindingErrorEnum,
)
from google.ads.googleads.v8.errors.types.policy_validation_parameter_error import (
    PolicyValidationParameterErrorEnum as PolicyValidationParameterErrorEnum,
)
from google.ads.googleads.v8.errors.types.policy_violation_error import (
    PolicyViolationErrorEnum as PolicyViolationErrorEnum,
)
from google.ads.googleads.v8.errors.types.query_error import (
    QueryErrorEnum as QueryErrorEnum,
)
from google.ads.googleads.v8.errors.types.quota_error import (
    QuotaErrorEnum as QuotaErrorEnum,
)
from google.ads.googleads.v8.errors.types.range_error import (
    RangeErrorEnum as RangeErrorEnum,
)
from google.ads.googleads.v8.errors.types.reach_plan_error import (
    ReachPlanErrorEnum as ReachPlanErrorEnum,
)
from google.ads.googleads.v8.errors.types.recommendation_error import (
    RecommendationErrorEnum as RecommendationErrorEnum,
)
from google.ads.googleads.v8.errors.types.region_code_error import (
    RegionCodeErrorEnum as RegionCodeErrorEnum,
)
from google.ads.googleads.v8.errors.types.request_error import (
    RequestErrorEnum as RequestErrorEnum,
)
from google.ads.googleads.v8.errors.types.resource_access_denied_error import (
    ResourceAccessDeniedErrorEnum as ResourceAccessDeniedErrorEnum,
)
from google.ads.googleads.v8.errors.types.resource_count_limit_exceeded_error import (
    ResourceCountLimitExceededErrorEnum as ResourceCountLimitExceededErrorEnum,
)
from google.ads.googleads.v8.errors.types.setting_error import (
    SettingErrorEnum as SettingErrorEnum,
)
from google.ads.googleads.v8.errors.types.shared_criterion_error import (
    SharedCriterionErrorEnum as SharedCriterionErrorEnum,
)
from google.ads.googleads.v8.errors.types.shared_set_error import (
    SharedSetErrorEnum as SharedSetErrorEnum,
)
from google.ads.googleads.v8.errors.types.size_limit_error import (
    SizeLimitErrorEnum as SizeLimitErrorEnum,
)
from google.ads.googleads.v8.errors.types.string_format_error import (
    StringFormatErrorEnum as StringFormatErrorEnum,
)
from google.ads.googleads.v8.errors.types.string_length_error import (
    StringLengthErrorEnum as StringLengthErrorEnum,
)
from google.ads.googleads.v8.errors.types.third_party_app_analytics_link_error import (
    ThirdPartyAppAnalyticsLinkErrorEnum as ThirdPartyAppAnalyticsLinkErrorEnum,
)
from google.ads.googleads.v8.errors.types.time_zone_error import (
    TimeZoneErrorEnum as TimeZoneErrorEnum,
)
from google.ads.googleads.v8.errors.types.url_field_error import (
    UrlFieldErrorEnum as UrlFieldErrorEnum,
)
from google.ads.googleads.v8.errors.types.user_data_error import (
    UserDataErrorEnum as UserDataErrorEnum,
)
from google.ads.googleads.v8.errors.types.user_list_error import (
    UserListErrorEnum as UserListErrorEnum,
)
from google.ads.googleads.v8.errors.types.youtube_video_registration_error import (
    YoutubeVideoRegistrationErrorEnum as YoutubeVideoRegistrationErrorEnum,
)
from google.ads.googleads.v8.resources.types.accessible_bidding_strategy import (
    AccessibleBiddingStrategy as AccessibleBiddingStrategy,
)
from google.ads.googleads.v8.resources.types.account_budget import (
    AccountBudget as AccountBudget,
)
from google.ads.googleads.v8.resources.types.account_budget_proposal import (
    AccountBudgetProposal as AccountBudgetProposal,
)
from google.ads.googleads.v8.resources.types.account_link import (
    AccountLink as AccountLink,
    DataPartnerLinkIdentifier as DataPartnerLinkIdentifier,
    GoogleAdsLinkIdentifier as GoogleAdsLinkIdentifier,
    ThirdPartyAppAnalyticsLinkIdentifier as ThirdPartyAppAnalyticsLinkIdentifier,
)
from google.ads.googleads.v8.resources.types.ad import Ad as Ad
from google.ads.googleads.v8.resources.types.ad_group import AdGroup as AdGroup
from google.ads.googleads.v8.resources.types.ad_group_ad import (
    AdGroupAd as AdGroupAd,
    AdGroupAdPolicySummary as AdGroupAdPolicySummary,
)
from google.ads.googleads.v8.resources.types.ad_group_ad_asset_view import (
    AdGroupAdAssetPolicySummary as AdGroupAdAssetPolicySummary,
    AdGroupAdAssetView as AdGroupAdAssetView,
)
from google.ads.googleads.v8.resources.types.ad_group_ad_label import (
    AdGroupAdLabel as AdGroupAdLabel,
)
from google.ads.googleads.v8.resources.types.ad_group_asset import (
    AdGroupAsset as AdGroupAsset,
)
from google.ads.googleads.v8.resources.types.ad_group_audience_view import (
    AdGroupAudienceView as AdGroupAudienceView,
)
from google.ads.googleads.v8.resources.types.ad_group_bid_modifier import (
    AdGroupBidModifier as AdGroupBidModifier,
)
from google.ads.googleads.v8.resources.types.ad_group_criterion import (
    AdGroupCriterion as AdGroupCriterion,
)
from google.ads.googleads.v8.resources.types.ad_group_criterion_label import (
    AdGroupCriterionLabel as AdGroupCriterionLabel,
)
from google.ads.googleads.v8.resources.types.ad_group_criterion_simulation import (
    AdGroupCriterionSimulation as AdGroupCriterionSimulation,
)
from google.ads.googleads.v8.resources.types.ad_group_extension_setting import (
    AdGroupExtensionSetting as AdGroupExtensionSetting,
)
from google.ads.googleads.v8.resources.types.ad_group_feed import (
    AdGroupFeed as AdGroupFeed,
)
from google.ads.googleads.v8.resources.types.ad_group_label import (
    AdGroupLabel as AdGroupLabel,
)
from google.ads.googleads.v8.resources.types.ad_group_simulation import (
    AdGroupSimulation as AdGroupSimulation,
)
from google.ads.googleads.v8.resources.types.ad_parameter import (
    AdParameter as AdParameter,
)
from google.ads.googleads.v8.resources.types.ad_schedule_view import (
    AdScheduleView as AdScheduleView,
)
from google.ads.googleads.v8.resources.types.age_range_view import (
    AgeRangeView as AgeRangeView,
)
from google.ads.googleads.v8.resources.types.asset import (
    Asset as Asset,
    AssetPolicySummary as AssetPolicySummary,
)
from google.ads.googleads.v8.resources.types.asset_field_type_view import (
    AssetFieldTypeView as AssetFieldTypeView,
)
from google.ads.googleads.v8.resources.types.batch_job import BatchJob as BatchJob
from google.ads.googleads.v8.resources.types.bidding_data_exclusion import (
    BiddingDataExclusion as BiddingDataExclusion,
)
from google.ads.googleads.v8.resources.types.bidding_seasonality_adjustment import (
    BiddingSeasonalityAdjustment as BiddingSeasonalityAdjustment,
)
from google.ads.googleads.v8.resources.types.bidding_strategy import (
    BiddingStrategy as BiddingStrategy,
)
from google.ads.googleads.v8.resources.types.bidding_strategy_simulation import (
    BiddingStrategySimulation as BiddingStrategySimulation,
)
from google.ads.googleads.v8.resources.types.billing_setup import (
    BillingSetup as BillingSetup,
)
from google.ads.googleads.v8.resources.types.call_view import CallView as CallView
from google.ads.googleads.v8.resources.types.campaign import Campaign as Campaign
from google.ads.googleads.v8.resources.types.campaign_asset import (
    CampaignAsset as CampaignAsset,
)
from google.ads.googleads.v8.resources.types.campaign_audience_view import (
    CampaignAudienceView as CampaignAudienceView,
)
from google.ads.googleads.v8.resources.types.campaign_bid_modifier import (
    CampaignBidModifier as CampaignBidModifier,
)
from google.ads.googleads.v8.resources.types.campaign_budget import (
    CampaignBudget as CampaignBudget,
)
from google.ads.googleads.v8.resources.types.campaign_criterion import (
    CampaignCriterion as CampaignCriterion,
)
from google.ads.googleads.v8.resources.types.campaign_criterion_simulation import (
    CampaignCriterionSimulation as CampaignCriterionSimulation,
)
from google.ads.googleads.v8.resources.types.campaign_draft import (
    CampaignDraft as CampaignDraft,
)
from google.ads.googleads.v8.resources.types.campaign_experiment import (
    CampaignExperiment as CampaignExperiment,
)
from google.ads.googleads.v8.resources.types.campaign_extension_setting import (
    CampaignExtensionSetting as CampaignExtensionSetting,
)
from google.ads.googleads.v8.resources.types.campaign_feed import (
    CampaignFeed as CampaignFeed,
)
from google.ads.googleads.v8.resources.types.campaign_label import (
    CampaignLabel as CampaignLabel,
)
from google.ads.googleads.v8.resources.types.campaign_shared_set import (
    CampaignSharedSet as CampaignSharedSet,
)
from google.ads.googleads.v8.resources.types.campaign_simulation import (
    CampaignSimulation as CampaignSimulation,
)
from google.ads.googleads.v8.resources.types.carrier_constant import (
    CarrierConstant as CarrierConstant,
)
from google.ads.googleads.v8.resources.types.change_event import (
    ChangeEvent as ChangeEvent,
)
from google.ads.googleads.v8.resources.types.change_status import (
    ChangeStatus as ChangeStatus,
)
from google.ads.googleads.v8.resources.types.click_view import ClickView as ClickView
from google.ads.googleads.v8.resources.types.combined_audience import (
    CombinedAudience as CombinedAudience,
)
from google.ads.googleads.v8.resources.types.conversion_action import (
    ConversionAction as ConversionAction,
)
from google.ads.googleads.v8.resources.types.conversion_custom_variable import (
    ConversionCustomVariable as ConversionCustomVariable,
)
from google.ads.googleads.v8.resources.types.conversion_value_rule import (
    ConversionValueRule as ConversionValueRule,
)
from google.ads.googleads.v8.resources.types.conversion_value_rule_set import (
    ConversionValueRuleSet as ConversionValueRuleSet,
)
from google.ads.googleads.v8.resources.types.currency_constant import (
    CurrencyConstant as CurrencyConstant,
)
from google.ads.googleads.v8.resources.types.custom_audience import (
    CustomAudience as CustomAudience,
    CustomAudienceMember as CustomAudienceMember,
)
from google.ads.googleads.v8.resources.types.custom_interest import (
    CustomInterest as CustomInterest,
    CustomInterestMember as CustomInterestMember,
)
from google.ads.googleads.v8.resources.types.customer import (
    CallReportingSetting as CallReportingSetting,
    ConversionTrackingSetting as ConversionTrackingSetting,
    Customer as Customer,
    RemarketingSetting as RemarketingSetting,
)
from google.ads.googleads.v8.resources.types.customer_asset import (
    CustomerAsset as CustomerAsset,
)
from google.ads.googleads.v8.resources.types.customer_client import (
    CustomerClient as CustomerClient,
)
from google.ads.googleads.v8.resources.types.customer_client_link import (
    CustomerClientLink as CustomerClientLink,
)
from google.ads.googleads.v8.resources.types.customer_extension_setting import (
    CustomerExtensionSetting as CustomerExtensionSetting,
)
from google.ads.googleads.v8.resources.types.customer_feed import (
    CustomerFeed as CustomerFeed,
)
from google.ads.googleads.v8.resources.types.customer_label import (
    CustomerLabel as CustomerLabel,
)
from google.ads.googleads.v8.resources.types.customer_manager_link import (
    CustomerManagerLink as CustomerManagerLink,
)
from google.ads.googleads.v8.resources.types.customer_negative_criterion import (
    CustomerNegativeCriterion as CustomerNegativeCriterion,
)
from google.ads.googleads.v8.resources.types.customer_user_access import (
    CustomerUserAccess as CustomerUserAccess,
)
from google.ads.googleads.v8.resources.types.customer_user_access_invitation import (
    CustomerUserAccessInvitation as CustomerUserAccessInvitation,
)
from google.ads.googleads.v8.resources.types.detail_placement_view import (
    DetailPlacementView as DetailPlacementView,
)
from google.ads.googleads.v8.resources.types.detailed_demographic import (
    DetailedDemographic as DetailedDemographic,
)
from google.ads.googleads.v8.resources.types.display_keyword_view import (
    DisplayKeywordView as DisplayKeywordView,
)
from google.ads.googleads.v8.resources.types.distance_view import (
    DistanceView as DistanceView,
)
from google.ads.googleads.v8.resources.types.domain_category import (
    DomainCategory as DomainCategory,
)
from google.ads.googleads.v8.resources.types.dynamic_search_ads_search_term_view import (
    DynamicSearchAdsSearchTermView as DynamicSearchAdsSearchTermView,
)
from google.ads.googleads.v8.resources.types.expanded_landing_page_view import (
    ExpandedLandingPageView as ExpandedLandingPageView,
)
from google.ads.googleads.v8.resources.types.extension_feed_item import (
    ExtensionFeedItem as ExtensionFeedItem,
)
from google.ads.googleads.v8.resources.types.feed import (
    Feed as Feed,
    FeedAttribute as FeedAttribute,
    FeedAttributeOperation as FeedAttributeOperation,
)
from google.ads.googleads.v8.resources.types.feed_item import (
    FeedItem as FeedItem,
    FeedItemAttributeValue as FeedItemAttributeValue,
    FeedItemPlaceholderPolicyInfo as FeedItemPlaceholderPolicyInfo,
    FeedItemValidationError as FeedItemValidationError,
)
from google.ads.googleads.v8.resources.types.feed_item_set import (
    FeedItemSet as FeedItemSet,
)
from google.ads.googleads.v8.resources.types.feed_item_set_link import (
    FeedItemSetLink as FeedItemSetLink,
)
from google.ads.googleads.v8.resources.types.feed_item_target import (
    FeedItemTarget as FeedItemTarget,
)
from google.ads.googleads.v8.resources.types.feed_mapping import (
    AttributeFieldMapping as AttributeFieldMapping,
    FeedMapping as FeedMapping,
)
from google.ads.googleads.v8.resources.types.feed_placeholder_view import (
    FeedPlaceholderView as FeedPlaceholderView,
)
from google.ads.googleads.v8.resources.types.gender_view import GenderView as GenderView
from google.ads.googleads.v8.resources.types.geo_target_constant import (
    GeoTargetConstant as GeoTargetConstant,
)
from google.ads.googleads.v8.resources.types.geographic_view import (
    GeographicView as GeographicView,
)
from google.ads.googleads.v8.resources.types.google_ads_field import (
    GoogleAdsField as GoogleAdsField,
)
from google.ads.googleads.v8.resources.types.group_placement_view import (
    GroupPlacementView as GroupPlacementView,
)
from google.ads.googleads.v8.resources.types.hotel_group_view import (
    HotelGroupView as HotelGroupView,
)
from google.ads.googleads.v8.resources.types.hotel_performance_view import (
    HotelPerformanceView as HotelPerformanceView,
)
from google.ads.googleads.v8.resources.types.income_range_view import (
    IncomeRangeView as IncomeRangeView,
)
from google.ads.googleads.v8.resources.types.invoice import Invoice as Invoice
from google.ads.googleads.v8.resources.types.keyword_plan import (
    KeywordPlan as KeywordPlan,
    KeywordPlanForecastPeriod as KeywordPlanForecastPeriod,
)
from google.ads.googleads.v8.resources.types.keyword_plan_ad_group import (
    KeywordPlanAdGroup as KeywordPlanAdGroup,
)
from google.ads.googleads.v8.resources.types.keyword_plan_ad_group_keyword import (
    KeywordPlanAdGroupKeyword as KeywordPlanAdGroupKeyword,
)
from google.ads.googleads.v8.resources.types.keyword_plan_campaign import (
    KeywordPlanCampaign as KeywordPlanCampaign,
    KeywordPlanGeoTarget as KeywordPlanGeoTarget,
)
from google.ads.googleads.v8.resources.types.keyword_plan_campaign_keyword import (
    KeywordPlanCampaignKeyword as KeywordPlanCampaignKeyword,
)
from google.ads.googleads.v8.resources.types.keyword_theme_constant import (
    KeywordThemeConstant as KeywordThemeConstant,
)
from google.ads.googleads.v8.resources.types.keyword_view import (
    KeywordView as KeywordView,
)
from google.ads.googleads.v8.resources.types.label import Label as Label
from google.ads.googleads.v8.resources.types.landing_page_view import (
    LandingPageView as LandingPageView,
)
from google.ads.googleads.v8.resources.types.language_constant import (
    LanguageConstant as LanguageConstant,
)
from google.ads.googleads.v8.resources.types.life_event import LifeEvent as LifeEvent
from google.ads.googleads.v8.resources.types.location_view import (
    LocationView as LocationView,
)
from google.ads.googleads.v8.resources.types.managed_placement_view import (
    ManagedPlacementView as ManagedPlacementView,
)
from google.ads.googleads.v8.resources.types.media_file import (
    MediaAudio as MediaAudio,
    MediaBundle as MediaBundle,
    MediaFile as MediaFile,
    MediaImage as MediaImage,
    MediaVideo as MediaVideo,
)
from google.ads.googleads.v8.resources.types.merchant_center_link import (
    MerchantCenterLink as MerchantCenterLink,
)
from google.ads.googleads.v8.resources.types.mobile_app_category_constant import (
    MobileAppCategoryConstant as MobileAppCategoryConstant,
)
from google.ads.googleads.v8.resources.types.mobile_device_constant import (
    MobileDeviceConstant as MobileDeviceConstant,
)
from google.ads.googleads.v8.resources.types.offline_user_data_job import (
    OfflineUserDataJob as OfflineUserDataJob,
)
from google.ads.googleads.v8.resources.types.operating_system_version_constant import (
    OperatingSystemVersionConstant as OperatingSystemVersionConstant,
)
from google.ads.googleads.v8.resources.types.paid_organic_search_term_view import (
    PaidOrganicSearchTermView as PaidOrganicSearchTermView,
)
from google.ads.googleads.v8.resources.types.parental_status_view import (
    ParentalStatusView as ParentalStatusView,
)
from google.ads.googleads.v8.resources.types.payments_account import (
    PaymentsAccount as PaymentsAccount,
)
from google.ads.googleads.v8.resources.types.product_bidding_category_constant import (
    ProductBiddingCategoryConstant as ProductBiddingCategoryConstant,
)
from google.ads.googleads.v8.resources.types.product_group_view import (
    ProductGroupView as ProductGroupView,
)
from google.ads.googleads.v8.resources.types.recommendation import (
    Recommendation as Recommendation,
)
from google.ads.googleads.v8.resources.types.remarketing_action import (
    RemarketingAction as RemarketingAction,
)
from google.ads.googleads.v8.resources.types.search_term_view import (
    SearchTermView as SearchTermView,
)
from google.ads.googleads.v8.resources.types.shared_criterion import (
    SharedCriterion as SharedCriterion,
)
from google.ads.googleads.v8.resources.types.shared_set import SharedSet as SharedSet
from google.ads.googleads.v8.resources.types.shopping_performance_view import (
    ShoppingPerformanceView as ShoppingPerformanceView,
)
from google.ads.googleads.v8.resources.types.smart_campaign_search_term_view import (
    SmartCampaignSearchTermView as SmartCampaignSearchTermView,
)
from google.ads.googleads.v8.resources.types.smart_campaign_setting import (
    SmartCampaignSetting as SmartCampaignSetting,
)
from google.ads.googleads.v8.resources.types.third_party_app_analytics_link import (
    ThirdPartyAppAnalyticsLink as ThirdPartyAppAnalyticsLink,
)
from google.ads.googleads.v8.resources.types.topic_constant import (
    TopicConstant as TopicConstant,
)
from google.ads.googleads.v8.resources.types.topic_view import TopicView as TopicView
from google.ads.googleads.v8.resources.types.user_interest import (
    UserInterest as UserInterest,
)
from google.ads.googleads.v8.resources.types.user_list import UserList as UserList
from google.ads.googleads.v8.resources.types.user_location_view import (
    UserLocationView as UserLocationView,
)
from google.ads.googleads.v8.resources.types.video import Video as Video
from google.ads.googleads.v8.resources.types.webpage_view import (
    WebpageView as WebpageView,
)
from google.ads.googleads.v8.services.services.accessible_bidding_strategy_service import (
    AccessibleBiddingStrategyServiceClient as AccessibleBiddingStrategyServiceClient,
)
from google.ads.googleads.v8.services.services.accessible_bidding_strategy_service.transports import (
    AccessibleBiddingStrategyServiceGrpcTransport as AccessibleBiddingStrategyServiceGrpcTransport,
    AccessibleBiddingStrategyServiceTransport as AccessibleBiddingStrategyServiceTransport,
)
from google.ads.googleads.v8.services.services.account_budget_proposal_service import (
    AccountBudgetProposalServiceClient as AccountBudgetProposalServiceClient,
)
from google.ads.googleads.v8.services.services.account_budget_proposal_service.transports import (
    AccountBudgetProposalServiceGrpcTransport as AccountBudgetProposalServiceGrpcTransport,
    AccountBudgetProposalServiceTransport as AccountBudgetProposalServiceTransport,
)
from google.ads.googleads.v8.services.services.account_budget_service import (
    AccountBudgetServiceClient as AccountBudgetServiceClient,
)
from google.ads.googleads.v8.services.services.account_budget_service.transports import (
    AccountBudgetServiceGrpcTransport as AccountBudgetServiceGrpcTransport,
    AccountBudgetServiceTransport as AccountBudgetServiceTransport,
)
from google.ads.googleads.v8.services.services.account_link_service import (
    AccountLinkServiceClient as AccountLinkServiceClient,
)
from google.ads.googleads.v8.services.services.account_link_service.transports import (
    AccountLinkServiceGrpcTransport as AccountLinkServiceGrpcTransport,
    AccountLinkServiceTransport as AccountLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_ad_asset_view_service import (
    AdGroupAdAssetViewServiceClient as AdGroupAdAssetViewServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_ad_asset_view_service.transports import (
    AdGroupAdAssetViewServiceGrpcTransport as AdGroupAdAssetViewServiceGrpcTransport,
    AdGroupAdAssetViewServiceTransport as AdGroupAdAssetViewServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_ad_label_service import (
    AdGroupAdLabelServiceClient as AdGroupAdLabelServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_ad_label_service.transports import (
    AdGroupAdLabelServiceGrpcTransport as AdGroupAdLabelServiceGrpcTransport,
    AdGroupAdLabelServiceTransport as AdGroupAdLabelServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_ad_service import (
    AdGroupAdServiceClient as AdGroupAdServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_ad_service.transports import (
    AdGroupAdServiceGrpcTransport as AdGroupAdServiceGrpcTransport,
    AdGroupAdServiceTransport as AdGroupAdServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_asset_service import (
    AdGroupAssetServiceClient as AdGroupAssetServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_asset_service.transports import (
    AdGroupAssetServiceGrpcTransport as AdGroupAssetServiceGrpcTransport,
    AdGroupAssetServiceTransport as AdGroupAssetServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_audience_view_service import (
    AdGroupAudienceViewServiceClient as AdGroupAudienceViewServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_audience_view_service.transports import (
    AdGroupAudienceViewServiceGrpcTransport as AdGroupAudienceViewServiceGrpcTransport,
    AdGroupAudienceViewServiceTransport as AdGroupAudienceViewServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_bid_modifier_service import (
    AdGroupBidModifierServiceClient as AdGroupBidModifierServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_bid_modifier_service.transports import (
    AdGroupBidModifierServiceGrpcTransport as AdGroupBidModifierServiceGrpcTransport,
    AdGroupBidModifierServiceTransport as AdGroupBidModifierServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_label_service import (
    AdGroupCriterionLabelServiceClient as AdGroupCriterionLabelServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_label_service.transports import (
    AdGroupCriterionLabelServiceGrpcTransport as AdGroupCriterionLabelServiceGrpcTransport,
    AdGroupCriterionLabelServiceTransport as AdGroupCriterionLabelServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_service import (
    AdGroupCriterionServiceClient as AdGroupCriterionServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_service.transports import (
    AdGroupCriterionServiceGrpcTransport as AdGroupCriterionServiceGrpcTransport,
    AdGroupCriterionServiceTransport as AdGroupCriterionServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_simulation_service import (
    AdGroupCriterionSimulationServiceClient as AdGroupCriterionSimulationServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_criterion_simulation_service.transports import (
    AdGroupCriterionSimulationServiceGrpcTransport as AdGroupCriterionSimulationServiceGrpcTransport,
    AdGroupCriterionSimulationServiceTransport as AdGroupCriterionSimulationServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_extension_setting_service import (
    AdGroupExtensionSettingServiceClient as AdGroupExtensionSettingServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_extension_setting_service.transports import (
    AdGroupExtensionSettingServiceGrpcTransport as AdGroupExtensionSettingServiceGrpcTransport,
    AdGroupExtensionSettingServiceTransport as AdGroupExtensionSettingServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_feed_service import (
    AdGroupFeedServiceClient as AdGroupFeedServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_feed_service.transports import (
    AdGroupFeedServiceGrpcTransport as AdGroupFeedServiceGrpcTransport,
    AdGroupFeedServiceTransport as AdGroupFeedServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_label_service import (
    AdGroupLabelServiceClient as AdGroupLabelServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_label_service.transports import (
    AdGroupLabelServiceGrpcTransport as AdGroupLabelServiceGrpcTransport,
    AdGroupLabelServiceTransport as AdGroupLabelServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_service import (
    AdGroupServiceClient as AdGroupServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_service.transports import (
    AdGroupServiceGrpcTransport as AdGroupServiceGrpcTransport,
    AdGroupServiceTransport as AdGroupServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_group_simulation_service import (
    AdGroupSimulationServiceClient as AdGroupSimulationServiceClient,
)
from google.ads.googleads.v8.services.services.ad_group_simulation_service.transports import (
    AdGroupSimulationServiceGrpcTransport as AdGroupSimulationServiceGrpcTransport,
    AdGroupSimulationServiceTransport as AdGroupSimulationServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_parameter_service import (
    AdParameterServiceClient as AdParameterServiceClient,
)
from google.ads.googleads.v8.services.services.ad_parameter_service.transports import (
    AdParameterServiceGrpcTransport as AdParameterServiceGrpcTransport,
    AdParameterServiceTransport as AdParameterServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_schedule_view_service import (
    AdScheduleViewServiceClient as AdScheduleViewServiceClient,
)
from google.ads.googleads.v8.services.services.ad_schedule_view_service.transports import (
    AdScheduleViewServiceGrpcTransport as AdScheduleViewServiceGrpcTransport,
    AdScheduleViewServiceTransport as AdScheduleViewServiceTransport,
)
from google.ads.googleads.v8.services.services.ad_service import (
    AdServiceClient as AdServiceClient,
)
from google.ads.googleads.v8.services.services.ad_service.transports import (
    AdServiceGrpcTransport as AdServiceGrpcTransport,
    AdServiceTransport as AdServiceTransport,
)
from google.ads.googleads.v8.services.services.age_range_view_service import (
    AgeRangeViewServiceClient as AgeRangeViewServiceClient,
)
from google.ads.googleads.v8.services.services.age_range_view_service.transports import (
    AgeRangeViewServiceGrpcTransport as AgeRangeViewServiceGrpcTransport,
    AgeRangeViewServiceTransport as AgeRangeViewServiceTransport,
)
from google.ads.googleads.v8.services.services.asset_field_type_view_service import (
    AssetFieldTypeViewServiceClient as AssetFieldTypeViewServiceClient,
)
from google.ads.googleads.v8.services.services.asset_field_type_view_service.transports import (
    AssetFieldTypeViewServiceGrpcTransport as AssetFieldTypeViewServiceGrpcTransport,
    AssetFieldTypeViewServiceTransport as AssetFieldTypeViewServiceTransport,
)
from google.ads.googleads.v8.services.services.asset_service import (
    AssetServiceClient as AssetServiceClient,
)
from google.ads.googleads.v8.services.services.asset_service.transports import (
    AssetServiceGrpcTransport as AssetServiceGrpcTransport,
    AssetServiceTransport as AssetServiceTransport,
)
from google.ads.googleads.v8.services.services.batch_job_service import (
    BatchJobServiceClient as BatchJobServiceClient,
)
from google.ads.googleads.v8.services.services.batch_job_service.transports import (
    BatchJobServiceGrpcTransport as BatchJobServiceGrpcTransport,
    BatchJobServiceTransport as BatchJobServiceTransport,
)
from google.ads.googleads.v8.services.services.bidding_data_exclusion_service import (
    BiddingDataExclusionServiceClient as BiddingDataExclusionServiceClient,
)
from google.ads.googleads.v8.services.services.bidding_data_exclusion_service.transports import (
    BiddingDataExclusionServiceGrpcTransport as BiddingDataExclusionServiceGrpcTransport,
    BiddingDataExclusionServiceTransport as BiddingDataExclusionServiceTransport,
)
from google.ads.googleads.v8.services.services.bidding_seasonality_adjustment_service import (
    BiddingSeasonalityAdjustmentServiceClient as BiddingSeasonalityAdjustmentServiceClient,
)
from google.ads.googleads.v8.services.services.bidding_seasonality_adjustment_service.transports import (
    BiddingSeasonalityAdjustmentServiceGrpcTransport as BiddingSeasonalityAdjustmentServiceGrpcTransport,
    BiddingSeasonalityAdjustmentServiceTransport as BiddingSeasonalityAdjustmentServiceTransport,
)
from google.ads.googleads.v8.services.services.bidding_strategy_service import (
    BiddingStrategyServiceClient as BiddingStrategyServiceClient,
)
from google.ads.googleads.v8.services.services.bidding_strategy_service.transports import (
    BiddingStrategyServiceGrpcTransport as BiddingStrategyServiceGrpcTransport,
    BiddingStrategyServiceTransport as BiddingStrategyServiceTransport,
)
from google.ads.googleads.v8.services.services.bidding_strategy_simulation_service import (
    BiddingStrategySimulationServiceClient as BiddingStrategySimulationServiceClient,
)
from google.ads.googleads.v8.services.services.bidding_strategy_simulation_service.transports import (
    BiddingStrategySimulationServiceGrpcTransport as BiddingStrategySimulationServiceGrpcTransport,
    BiddingStrategySimulationServiceTransport as BiddingStrategySimulationServiceTransport,
)
from google.ads.googleads.v8.services.services.billing_setup_service import (
    BillingSetupServiceClient as BillingSetupServiceClient,
)
from google.ads.googleads.v8.services.services.billing_setup_service.transports import (
    BillingSetupServiceGrpcTransport as BillingSetupServiceGrpcTransport,
    BillingSetupServiceTransport as BillingSetupServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_asset_service import (
    CampaignAssetServiceClient as CampaignAssetServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_asset_service.transports import (
    CampaignAssetServiceGrpcTransport as CampaignAssetServiceGrpcTransport,
    CampaignAssetServiceTransport as CampaignAssetServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_audience_view_service import (
    CampaignAudienceViewServiceClient as CampaignAudienceViewServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_audience_view_service.transports import (
    CampaignAudienceViewServiceGrpcTransport as CampaignAudienceViewServiceGrpcTransport,
    CampaignAudienceViewServiceTransport as CampaignAudienceViewServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_bid_modifier_service import (
    CampaignBidModifierServiceClient as CampaignBidModifierServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_bid_modifier_service.transports import (
    CampaignBidModifierServiceGrpcTransport as CampaignBidModifierServiceGrpcTransport,
    CampaignBidModifierServiceTransport as CampaignBidModifierServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_budget_service import (
    CampaignBudgetServiceClient as CampaignBudgetServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_budget_service.transports import (
    CampaignBudgetServiceGrpcTransport as CampaignBudgetServiceGrpcTransport,
    CampaignBudgetServiceTransport as CampaignBudgetServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_criterion_service import (
    CampaignCriterionServiceClient as CampaignCriterionServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_criterion_service.transports import (
    CampaignCriterionServiceGrpcTransport as CampaignCriterionServiceGrpcTransport,
    CampaignCriterionServiceTransport as CampaignCriterionServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_criterion_simulation_service import (
    CampaignCriterionSimulationServiceClient as CampaignCriterionSimulationServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_criterion_simulation_service.transports import (
    CampaignCriterionSimulationServiceGrpcTransport as CampaignCriterionSimulationServiceGrpcTransport,
    CampaignCriterionSimulationServiceTransport as CampaignCriterionSimulationServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_draft_service import (
    CampaignDraftServiceClient as CampaignDraftServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_draft_service.transports import (
    CampaignDraftServiceGrpcTransport as CampaignDraftServiceGrpcTransport,
    CampaignDraftServiceTransport as CampaignDraftServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_experiment_service import (
    CampaignExperimentServiceClient as CampaignExperimentServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_experiment_service.transports import (
    CampaignExperimentServiceGrpcTransport as CampaignExperimentServiceGrpcTransport,
    CampaignExperimentServiceTransport as CampaignExperimentServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_extension_setting_service import (
    CampaignExtensionSettingServiceClient as CampaignExtensionSettingServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_extension_setting_service.transports import (
    CampaignExtensionSettingServiceGrpcTransport as CampaignExtensionSettingServiceGrpcTransport,
    CampaignExtensionSettingServiceTransport as CampaignExtensionSettingServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_feed_service import (
    CampaignFeedServiceClient as CampaignFeedServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_feed_service.transports import (
    CampaignFeedServiceGrpcTransport as CampaignFeedServiceGrpcTransport,
    CampaignFeedServiceTransport as CampaignFeedServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_label_service import (
    CampaignLabelServiceClient as CampaignLabelServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_label_service.transports import (
    CampaignLabelServiceGrpcTransport as CampaignLabelServiceGrpcTransport,
    CampaignLabelServiceTransport as CampaignLabelServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_service import (
    CampaignServiceClient as CampaignServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_service.transports import (
    CampaignServiceGrpcTransport as CampaignServiceGrpcTransport,
    CampaignServiceTransport as CampaignServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_shared_set_service import (
    CampaignSharedSetServiceClient as CampaignSharedSetServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_shared_set_service.transports import (
    CampaignSharedSetServiceGrpcTransport as CampaignSharedSetServiceGrpcTransport,
    CampaignSharedSetServiceTransport as CampaignSharedSetServiceTransport,
)
from google.ads.googleads.v8.services.services.campaign_simulation_service import (
    CampaignSimulationServiceClient as CampaignSimulationServiceClient,
)
from google.ads.googleads.v8.services.services.campaign_simulation_service.transports import (
    CampaignSimulationServiceGrpcTransport as CampaignSimulationServiceGrpcTransport,
    CampaignSimulationServiceTransport as CampaignSimulationServiceTransport,
)
from google.ads.googleads.v8.services.services.carrier_constant_service import (
    CarrierConstantServiceClient as CarrierConstantServiceClient,
)
from google.ads.googleads.v8.services.services.carrier_constant_service.transports import (
    CarrierConstantServiceGrpcTransport as CarrierConstantServiceGrpcTransport,
    CarrierConstantServiceTransport as CarrierConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.change_status_service import (
    ChangeStatusServiceClient as ChangeStatusServiceClient,
)
from google.ads.googleads.v8.services.services.change_status_service.transports import (
    ChangeStatusServiceGrpcTransport as ChangeStatusServiceGrpcTransport,
    ChangeStatusServiceTransport as ChangeStatusServiceTransport,
)
from google.ads.googleads.v8.services.services.click_view_service import (
    ClickViewServiceClient as ClickViewServiceClient,
)
from google.ads.googleads.v8.services.services.click_view_service.transports import (
    ClickViewServiceGrpcTransport as ClickViewServiceGrpcTransport,
    ClickViewServiceTransport as ClickViewServiceTransport,
)
from google.ads.googleads.v8.services.services.combined_audience_service import (
    CombinedAudienceServiceClient as CombinedAudienceServiceClient,
)
from google.ads.googleads.v8.services.services.combined_audience_service.transports import (
    CombinedAudienceServiceGrpcTransport as CombinedAudienceServiceGrpcTransport,
    CombinedAudienceServiceTransport as CombinedAudienceServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_action_service import (
    ConversionActionServiceClient as ConversionActionServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_action_service.transports import (
    ConversionActionServiceGrpcTransport as ConversionActionServiceGrpcTransport,
    ConversionActionServiceTransport as ConversionActionServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_adjustment_upload_service import (
    ConversionAdjustmentUploadServiceClient as ConversionAdjustmentUploadServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_adjustment_upload_service.transports import (
    ConversionAdjustmentUploadServiceGrpcTransport as ConversionAdjustmentUploadServiceGrpcTransport,
    ConversionAdjustmentUploadServiceTransport as ConversionAdjustmentUploadServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_custom_variable_service import (
    ConversionCustomVariableServiceClient as ConversionCustomVariableServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_custom_variable_service.transports import (
    ConversionCustomVariableServiceGrpcTransport as ConversionCustomVariableServiceGrpcTransport,
    ConversionCustomVariableServiceTransport as ConversionCustomVariableServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_upload_service import (
    ConversionUploadServiceClient as ConversionUploadServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_upload_service.transports import (
    ConversionUploadServiceGrpcTransport as ConversionUploadServiceGrpcTransport,
    ConversionUploadServiceTransport as ConversionUploadServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_value_rule_service import (
    ConversionValueRuleServiceClient as ConversionValueRuleServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_value_rule_service.transports import (
    ConversionValueRuleServiceGrpcTransport as ConversionValueRuleServiceGrpcTransport,
    ConversionValueRuleServiceTransport as ConversionValueRuleServiceTransport,
)
from google.ads.googleads.v8.services.services.conversion_value_rule_set_service import (
    ConversionValueRuleSetServiceClient as ConversionValueRuleSetServiceClient,
)
from google.ads.googleads.v8.services.services.conversion_value_rule_set_service.transports import (
    ConversionValueRuleSetServiceGrpcTransport as ConversionValueRuleSetServiceGrpcTransport,
    ConversionValueRuleSetServiceTransport as ConversionValueRuleSetServiceTransport,
)
from google.ads.googleads.v8.services.services.currency_constant_service import (
    CurrencyConstantServiceClient as CurrencyConstantServiceClient,
)
from google.ads.googleads.v8.services.services.currency_constant_service.transports import (
    CurrencyConstantServiceGrpcTransport as CurrencyConstantServiceGrpcTransport,
    CurrencyConstantServiceTransport as CurrencyConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.custom_audience_service import (
    CustomAudienceServiceClient as CustomAudienceServiceClient,
)
from google.ads.googleads.v8.services.services.custom_audience_service.transports import (
    CustomAudienceServiceGrpcTransport as CustomAudienceServiceGrpcTransport,
    CustomAudienceServiceTransport as CustomAudienceServiceTransport,
)
from google.ads.googleads.v8.services.services.custom_interest_service import (
    CustomInterestServiceClient as CustomInterestServiceClient,
)
from google.ads.googleads.v8.services.services.custom_interest_service.transports import (
    CustomInterestServiceGrpcTransport as CustomInterestServiceGrpcTransport,
    CustomInterestServiceTransport as CustomInterestServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_asset_service import (
    CustomerAssetServiceClient as CustomerAssetServiceClient,
)
from google.ads.googleads.v8.services.services.customer_asset_service.transports import (
    CustomerAssetServiceGrpcTransport as CustomerAssetServiceGrpcTransport,
    CustomerAssetServiceTransport as CustomerAssetServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_client_link_service import (
    CustomerClientLinkServiceClient as CustomerClientLinkServiceClient,
)
from google.ads.googleads.v8.services.services.customer_client_link_service.transports import (
    CustomerClientLinkServiceGrpcTransport as CustomerClientLinkServiceGrpcTransport,
    CustomerClientLinkServiceTransport as CustomerClientLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_client_service import (
    CustomerClientServiceClient as CustomerClientServiceClient,
)
from google.ads.googleads.v8.services.services.customer_client_service.transports import (
    CustomerClientServiceGrpcTransport as CustomerClientServiceGrpcTransport,
    CustomerClientServiceTransport as CustomerClientServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_extension_setting_service import (
    CustomerExtensionSettingServiceClient as CustomerExtensionSettingServiceClient,
)
from google.ads.googleads.v8.services.services.customer_extension_setting_service.transports import (
    CustomerExtensionSettingServiceGrpcTransport as CustomerExtensionSettingServiceGrpcTransport,
    CustomerExtensionSettingServiceTransport as CustomerExtensionSettingServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_feed_service import (
    CustomerFeedServiceClient as CustomerFeedServiceClient,
)
from google.ads.googleads.v8.services.services.customer_feed_service.transports import (
    CustomerFeedServiceGrpcTransport as CustomerFeedServiceGrpcTransport,
    CustomerFeedServiceTransport as CustomerFeedServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_label_service import (
    CustomerLabelServiceClient as CustomerLabelServiceClient,
)
from google.ads.googleads.v8.services.services.customer_label_service.transports import (
    CustomerLabelServiceGrpcTransport as CustomerLabelServiceGrpcTransport,
    CustomerLabelServiceTransport as CustomerLabelServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_manager_link_service import (
    CustomerManagerLinkServiceClient as CustomerManagerLinkServiceClient,
)
from google.ads.googleads.v8.services.services.customer_manager_link_service.transports import (
    CustomerManagerLinkServiceGrpcTransport as CustomerManagerLinkServiceGrpcTransport,
    CustomerManagerLinkServiceTransport as CustomerManagerLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_negative_criterion_service import (
    CustomerNegativeCriterionServiceClient as CustomerNegativeCriterionServiceClient,
)
from google.ads.googleads.v8.services.services.customer_negative_criterion_service.transports import (
    CustomerNegativeCriterionServiceGrpcTransport as CustomerNegativeCriterionServiceGrpcTransport,
    CustomerNegativeCriterionServiceTransport as CustomerNegativeCriterionServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_service import (
    CustomerServiceClient as CustomerServiceClient,
)
from google.ads.googleads.v8.services.services.customer_service.transports import (
    CustomerServiceGrpcTransport as CustomerServiceGrpcTransport,
    CustomerServiceTransport as CustomerServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_user_access_invitation_service import (
    CustomerUserAccessInvitationServiceClient as CustomerUserAccessInvitationServiceClient,
)
from google.ads.googleads.v8.services.services.customer_user_access_invitation_service.transports import (
    CustomerUserAccessInvitationServiceGrpcTransport as CustomerUserAccessInvitationServiceGrpcTransport,
    CustomerUserAccessInvitationServiceTransport as CustomerUserAccessInvitationServiceTransport,
)
from google.ads.googleads.v8.services.services.customer_user_access_service import (
    CustomerUserAccessServiceClient as CustomerUserAccessServiceClient,
)
from google.ads.googleads.v8.services.services.customer_user_access_service.transports import (
    CustomerUserAccessServiceGrpcTransport as CustomerUserAccessServiceGrpcTransport,
    CustomerUserAccessServiceTransport as CustomerUserAccessServiceTransport,
)
from google.ads.googleads.v8.services.services.detail_placement_view_service import (
    DetailPlacementViewServiceClient as DetailPlacementViewServiceClient,
)
from google.ads.googleads.v8.services.services.detail_placement_view_service.transports import (
    DetailPlacementViewServiceGrpcTransport as DetailPlacementViewServiceGrpcTransport,
    DetailPlacementViewServiceTransport as DetailPlacementViewServiceTransport,
)
from google.ads.googleads.v8.services.services.detailed_demographic_service import (
    DetailedDemographicServiceClient as DetailedDemographicServiceClient,
)
from google.ads.googleads.v8.services.services.detailed_demographic_service.transports import (
    DetailedDemographicServiceGrpcTransport as DetailedDemographicServiceGrpcTransport,
    DetailedDemographicServiceTransport as DetailedDemographicServiceTransport,
)
from google.ads.googleads.v8.services.services.display_keyword_view_service import (
    DisplayKeywordViewServiceClient as DisplayKeywordViewServiceClient,
)
from google.ads.googleads.v8.services.services.display_keyword_view_service.transports import (
    DisplayKeywordViewServiceGrpcTransport as DisplayKeywordViewServiceGrpcTransport,
    DisplayKeywordViewServiceTransport as DisplayKeywordViewServiceTransport,
)
from google.ads.googleads.v8.services.services.distance_view_service import (
    DistanceViewServiceClient as DistanceViewServiceClient,
)
from google.ads.googleads.v8.services.services.distance_view_service.transports import (
    DistanceViewServiceGrpcTransport as DistanceViewServiceGrpcTransport,
    DistanceViewServiceTransport as DistanceViewServiceTransport,
)
from google.ads.googleads.v8.services.services.domain_category_service import (
    DomainCategoryServiceClient as DomainCategoryServiceClient,
)
from google.ads.googleads.v8.services.services.domain_category_service.transports import (
    DomainCategoryServiceGrpcTransport as DomainCategoryServiceGrpcTransport,
    DomainCategoryServiceTransport as DomainCategoryServiceTransport,
)
from google.ads.googleads.v8.services.services.dynamic_search_ads_search_term_view_service import (
    DynamicSearchAdsSearchTermViewServiceClient as DynamicSearchAdsSearchTermViewServiceClient,
)
from google.ads.googleads.v8.services.services.dynamic_search_ads_search_term_view_service.transports import (
    DynamicSearchAdsSearchTermViewServiceGrpcTransport as DynamicSearchAdsSearchTermViewServiceGrpcTransport,
    DynamicSearchAdsSearchTermViewServiceTransport as DynamicSearchAdsSearchTermViewServiceTransport,
)
from google.ads.googleads.v8.services.services.expanded_landing_page_view_service import (
    ExpandedLandingPageViewServiceClient as ExpandedLandingPageViewServiceClient,
)
from google.ads.googleads.v8.services.services.expanded_landing_page_view_service.transports import (
    ExpandedLandingPageViewServiceGrpcTransport as ExpandedLandingPageViewServiceGrpcTransport,
    ExpandedLandingPageViewServiceTransport as ExpandedLandingPageViewServiceTransport,
)
from google.ads.googleads.v8.services.services.extension_feed_item_service import (
    ExtensionFeedItemServiceClient as ExtensionFeedItemServiceClient,
)
from google.ads.googleads.v8.services.services.extension_feed_item_service.transports import (
    ExtensionFeedItemServiceGrpcTransport as ExtensionFeedItemServiceGrpcTransport,
    ExtensionFeedItemServiceTransport as ExtensionFeedItemServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_item_service import (
    FeedItemServiceClient as FeedItemServiceClient,
)
from google.ads.googleads.v8.services.services.feed_item_service.transports import (
    FeedItemServiceGrpcTransport as FeedItemServiceGrpcTransport,
    FeedItemServiceTransport as FeedItemServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_item_set_link_service import (
    FeedItemSetLinkServiceClient as FeedItemSetLinkServiceClient,
)
from google.ads.googleads.v8.services.services.feed_item_set_link_service.transports import (
    FeedItemSetLinkServiceGrpcTransport as FeedItemSetLinkServiceGrpcTransport,
    FeedItemSetLinkServiceTransport as FeedItemSetLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_item_set_service import (
    FeedItemSetServiceClient as FeedItemSetServiceClient,
)
from google.ads.googleads.v8.services.services.feed_item_set_service.transports import (
    FeedItemSetServiceGrpcTransport as FeedItemSetServiceGrpcTransport,
    FeedItemSetServiceTransport as FeedItemSetServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_item_target_service import (
    FeedItemTargetServiceClient as FeedItemTargetServiceClient,
)
from google.ads.googleads.v8.services.services.feed_item_target_service.transports import (
    FeedItemTargetServiceGrpcTransport as FeedItemTargetServiceGrpcTransport,
    FeedItemTargetServiceTransport as FeedItemTargetServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_mapping_service import (
    FeedMappingServiceClient as FeedMappingServiceClient,
)
from google.ads.googleads.v8.services.services.feed_mapping_service.transports import (
    FeedMappingServiceGrpcTransport as FeedMappingServiceGrpcTransport,
    FeedMappingServiceTransport as FeedMappingServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_placeholder_view_service import (
    FeedPlaceholderViewServiceClient as FeedPlaceholderViewServiceClient,
)
from google.ads.googleads.v8.services.services.feed_placeholder_view_service.transports import (
    FeedPlaceholderViewServiceGrpcTransport as FeedPlaceholderViewServiceGrpcTransport,
    FeedPlaceholderViewServiceTransport as FeedPlaceholderViewServiceTransport,
)
from google.ads.googleads.v8.services.services.feed_service import (
    FeedServiceClient as FeedServiceClient,
)
from google.ads.googleads.v8.services.services.feed_service.transports import (
    FeedServiceGrpcTransport as FeedServiceGrpcTransport,
    FeedServiceTransport as FeedServiceTransport,
)
from google.ads.googleads.v8.services.services.gender_view_service import (
    GenderViewServiceClient as GenderViewServiceClient,
)
from google.ads.googleads.v8.services.services.gender_view_service.transports import (
    GenderViewServiceGrpcTransport as GenderViewServiceGrpcTransport,
    GenderViewServiceTransport as GenderViewServiceTransport,
)
from google.ads.googleads.v8.services.services.geo_target_constant_service import (
    GeoTargetConstantServiceClient as GeoTargetConstantServiceClient,
)
from google.ads.googleads.v8.services.services.geo_target_constant_service.transports import (
    GeoTargetConstantServiceGrpcTransport as GeoTargetConstantServiceGrpcTransport,
    GeoTargetConstantServiceTransport as GeoTargetConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.geographic_view_service import (
    GeographicViewServiceClient as GeographicViewServiceClient,
)
from google.ads.googleads.v8.services.services.geographic_view_service.transports import (
    GeographicViewServiceGrpcTransport as GeographicViewServiceGrpcTransport,
    GeographicViewServiceTransport as GeographicViewServiceTransport,
)
from google.ads.googleads.v8.services.services.google_ads_field_service import (
    GoogleAdsFieldServiceClient as GoogleAdsFieldServiceClient,
)
from google.ads.googleads.v8.services.services.google_ads_field_service.transports import (
    GoogleAdsFieldServiceGrpcTransport as GoogleAdsFieldServiceGrpcTransport,
    GoogleAdsFieldServiceTransport as GoogleAdsFieldServiceTransport,
)
from google.ads.googleads.v8.services.services.google_ads_service import (
    GoogleAdsServiceClient as GoogleAdsServiceClient,
)
from google.ads.googleads.v8.services.services.google_ads_service.transports import (
    GoogleAdsServiceGrpcTransport as GoogleAdsServiceGrpcTransport,
    GoogleAdsServiceTransport as GoogleAdsServiceTransport,
)
from google.ads.googleads.v8.services.services.group_placement_view_service import (
    GroupPlacementViewServiceClient as GroupPlacementViewServiceClient,
)
from google.ads.googleads.v8.services.services.group_placement_view_service.transports import (
    GroupPlacementViewServiceGrpcTransport as GroupPlacementViewServiceGrpcTransport,
    GroupPlacementViewServiceTransport as GroupPlacementViewServiceTransport,
)
from google.ads.googleads.v8.services.services.hotel_group_view_service import (
    HotelGroupViewServiceClient as HotelGroupViewServiceClient,
)
from google.ads.googleads.v8.services.services.hotel_group_view_service.transports import (
    HotelGroupViewServiceGrpcTransport as HotelGroupViewServiceGrpcTransport,
    HotelGroupViewServiceTransport as HotelGroupViewServiceTransport,
)
from google.ads.googleads.v8.services.services.hotel_performance_view_service import (
    HotelPerformanceViewServiceClient as HotelPerformanceViewServiceClient,
)
from google.ads.googleads.v8.services.services.hotel_performance_view_service.transports import (
    HotelPerformanceViewServiceGrpcTransport as HotelPerformanceViewServiceGrpcTransport,
    HotelPerformanceViewServiceTransport as HotelPerformanceViewServiceTransport,
)
from google.ads.googleads.v8.services.services.income_range_view_service import (
    IncomeRangeViewServiceClient as IncomeRangeViewServiceClient,
)
from google.ads.googleads.v8.services.services.income_range_view_service.transports import (
    IncomeRangeViewServiceGrpcTransport as IncomeRangeViewServiceGrpcTransport,
    IncomeRangeViewServiceTransport as IncomeRangeViewServiceTransport,
)
from google.ads.googleads.v8.services.services.invoice_service import (
    InvoiceServiceClient as InvoiceServiceClient,
)
from google.ads.googleads.v8.services.services.invoice_service.transports import (
    InvoiceServiceGrpcTransport as InvoiceServiceGrpcTransport,
    InvoiceServiceTransport as InvoiceServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_ad_group_keyword_service import (
    KeywordPlanAdGroupKeywordServiceClient as KeywordPlanAdGroupKeywordServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_ad_group_keyword_service.transports import (
    KeywordPlanAdGroupKeywordServiceGrpcTransport as KeywordPlanAdGroupKeywordServiceGrpcTransport,
    KeywordPlanAdGroupKeywordServiceTransport as KeywordPlanAdGroupKeywordServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_ad_group_service import (
    KeywordPlanAdGroupServiceClient as KeywordPlanAdGroupServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_ad_group_service.transports import (
    KeywordPlanAdGroupServiceGrpcTransport as KeywordPlanAdGroupServiceGrpcTransport,
    KeywordPlanAdGroupServiceTransport as KeywordPlanAdGroupServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_campaign_keyword_service import (
    KeywordPlanCampaignKeywordServiceClient as KeywordPlanCampaignKeywordServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_campaign_keyword_service.transports import (
    KeywordPlanCampaignKeywordServiceGrpcTransport as KeywordPlanCampaignKeywordServiceGrpcTransport,
    KeywordPlanCampaignKeywordServiceTransport as KeywordPlanCampaignKeywordServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_campaign_service import (
    KeywordPlanCampaignServiceClient as KeywordPlanCampaignServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_campaign_service.transports import (
    KeywordPlanCampaignServiceGrpcTransport as KeywordPlanCampaignServiceGrpcTransport,
    KeywordPlanCampaignServiceTransport as KeywordPlanCampaignServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_idea_service import (
    KeywordPlanIdeaServiceClient as KeywordPlanIdeaServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_idea_service.transports import (
    KeywordPlanIdeaServiceGrpcTransport as KeywordPlanIdeaServiceGrpcTransport,
    KeywordPlanIdeaServiceTransport as KeywordPlanIdeaServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_plan_service import (
    KeywordPlanServiceClient as KeywordPlanServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_plan_service.transports import (
    KeywordPlanServiceGrpcTransport as KeywordPlanServiceGrpcTransport,
    KeywordPlanServiceTransport as KeywordPlanServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_theme_constant_service import (
    KeywordThemeConstantServiceClient as KeywordThemeConstantServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_theme_constant_service.transports import (
    KeywordThemeConstantServiceGrpcTransport as KeywordThemeConstantServiceGrpcTransport,
    KeywordThemeConstantServiceTransport as KeywordThemeConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.keyword_view_service import (
    KeywordViewServiceClient as KeywordViewServiceClient,
)
from google.ads.googleads.v8.services.services.keyword_view_service.transports import (
    KeywordViewServiceGrpcTransport as KeywordViewServiceGrpcTransport,
    KeywordViewServiceTransport as KeywordViewServiceTransport,
)
from google.ads.googleads.v8.services.services.label_service import (
    LabelServiceClient as LabelServiceClient,
)
from google.ads.googleads.v8.services.services.label_service.transports import (
    LabelServiceGrpcTransport as LabelServiceGrpcTransport,
    LabelServiceTransport as LabelServiceTransport,
)
from google.ads.googleads.v8.services.services.landing_page_view_service import (
    LandingPageViewServiceClient as LandingPageViewServiceClient,
)
from google.ads.googleads.v8.services.services.landing_page_view_service.transports import (
    LandingPageViewServiceGrpcTransport as LandingPageViewServiceGrpcTransport,
    LandingPageViewServiceTransport as LandingPageViewServiceTransport,
)
from google.ads.googleads.v8.services.services.language_constant_service import (
    LanguageConstantServiceClient as LanguageConstantServiceClient,
)
from google.ads.googleads.v8.services.services.language_constant_service.transports import (
    LanguageConstantServiceGrpcTransport as LanguageConstantServiceGrpcTransport,
    LanguageConstantServiceTransport as LanguageConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.life_event_service import (
    LifeEventServiceClient as LifeEventServiceClient,
)
from google.ads.googleads.v8.services.services.life_event_service.transports import (
    LifeEventServiceGrpcTransport as LifeEventServiceGrpcTransport,
    LifeEventServiceTransport as LifeEventServiceTransport,
)
from google.ads.googleads.v8.services.services.location_view_service import (
    LocationViewServiceClient as LocationViewServiceClient,
)
from google.ads.googleads.v8.services.services.location_view_service.transports import (
    LocationViewServiceGrpcTransport as LocationViewServiceGrpcTransport,
    LocationViewServiceTransport as LocationViewServiceTransport,
)
from google.ads.googleads.v8.services.services.managed_placement_view_service import (
    ManagedPlacementViewServiceClient as ManagedPlacementViewServiceClient,
)
from google.ads.googleads.v8.services.services.managed_placement_view_service.transports import (
    ManagedPlacementViewServiceGrpcTransport as ManagedPlacementViewServiceGrpcTransport,
    ManagedPlacementViewServiceTransport as ManagedPlacementViewServiceTransport,
)
from google.ads.googleads.v8.services.services.media_file_service import (
    MediaFileServiceClient as MediaFileServiceClient,
)
from google.ads.googleads.v8.services.services.media_file_service.transports import (
    MediaFileServiceGrpcTransport as MediaFileServiceGrpcTransport,
    MediaFileServiceTransport as MediaFileServiceTransport,
)
from google.ads.googleads.v8.services.services.merchant_center_link_service import (
    MerchantCenterLinkServiceClient as MerchantCenterLinkServiceClient,
)
from google.ads.googleads.v8.services.services.merchant_center_link_service.transports import (
    MerchantCenterLinkServiceGrpcTransport as MerchantCenterLinkServiceGrpcTransport,
    MerchantCenterLinkServiceTransport as MerchantCenterLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.mobile_app_category_constant_service import (
    MobileAppCategoryConstantServiceClient as MobileAppCategoryConstantServiceClient,
)
from google.ads.googleads.v8.services.services.mobile_app_category_constant_service.transports import (
    MobileAppCategoryConstantServiceGrpcTransport as MobileAppCategoryConstantServiceGrpcTransport,
    MobileAppCategoryConstantServiceTransport as MobileAppCategoryConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.mobile_device_constant_service import (
    MobileDeviceConstantServiceClient as MobileDeviceConstantServiceClient,
)
from google.ads.googleads.v8.services.services.mobile_device_constant_service.transports import (
    MobileDeviceConstantServiceGrpcTransport as MobileDeviceConstantServiceGrpcTransport,
    MobileDeviceConstantServiceTransport as MobileDeviceConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.offline_user_data_job_service import (
    OfflineUserDataJobServiceClient as OfflineUserDataJobServiceClient,
)
from google.ads.googleads.v8.services.services.offline_user_data_job_service.transports import (
    OfflineUserDataJobServiceGrpcTransport as OfflineUserDataJobServiceGrpcTransport,
    OfflineUserDataJobServiceTransport as OfflineUserDataJobServiceTransport,
)
from google.ads.googleads.v8.services.services.operating_system_version_constant_service import (
    OperatingSystemVersionConstantServiceClient as OperatingSystemVersionConstantServiceClient,
)
from google.ads.googleads.v8.services.services.operating_system_version_constant_service.transports import (
    OperatingSystemVersionConstantServiceGrpcTransport as OperatingSystemVersionConstantServiceGrpcTransport,
    OperatingSystemVersionConstantServiceTransport as OperatingSystemVersionConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.paid_organic_search_term_view_service import (
    PaidOrganicSearchTermViewServiceClient as PaidOrganicSearchTermViewServiceClient,
)
from google.ads.googleads.v8.services.services.paid_organic_search_term_view_service.transports import (
    PaidOrganicSearchTermViewServiceGrpcTransport as PaidOrganicSearchTermViewServiceGrpcTransport,
    PaidOrganicSearchTermViewServiceTransport as PaidOrganicSearchTermViewServiceTransport,
)
from google.ads.googleads.v8.services.services.parental_status_view_service import (
    ParentalStatusViewServiceClient as ParentalStatusViewServiceClient,
)
from google.ads.googleads.v8.services.services.parental_status_view_service.transports import (
    ParentalStatusViewServiceGrpcTransport as ParentalStatusViewServiceGrpcTransport,
    ParentalStatusViewServiceTransport as ParentalStatusViewServiceTransport,
)
from google.ads.googleads.v8.services.services.payments_account_service import (
    PaymentsAccountServiceClient as PaymentsAccountServiceClient,
)
from google.ads.googleads.v8.services.services.payments_account_service.transports import (
    PaymentsAccountServiceGrpcTransport as PaymentsAccountServiceGrpcTransport,
    PaymentsAccountServiceTransport as PaymentsAccountServiceTransport,
)
from google.ads.googleads.v8.services.services.product_bidding_category_constant_service import (
    ProductBiddingCategoryConstantServiceClient as ProductBiddingCategoryConstantServiceClient,
)
from google.ads.googleads.v8.services.services.product_bidding_category_constant_service.transports import (
    ProductBiddingCategoryConstantServiceGrpcTransport as ProductBiddingCategoryConstantServiceGrpcTransport,
    ProductBiddingCategoryConstantServiceTransport as ProductBiddingCategoryConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.product_group_view_service import (
    ProductGroupViewServiceClient as ProductGroupViewServiceClient,
)
from google.ads.googleads.v8.services.services.product_group_view_service.transports import (
    ProductGroupViewServiceGrpcTransport as ProductGroupViewServiceGrpcTransport,
    ProductGroupViewServiceTransport as ProductGroupViewServiceTransport,
)
from google.ads.googleads.v8.services.services.reach_plan_service import (
    ReachPlanServiceClient as ReachPlanServiceClient,
)
from google.ads.googleads.v8.services.services.reach_plan_service.transports import (
    ReachPlanServiceGrpcTransport as ReachPlanServiceGrpcTransport,
    ReachPlanServiceTransport as ReachPlanServiceTransport,
)
from google.ads.googleads.v8.services.services.recommendation_service import (
    RecommendationServiceClient as RecommendationServiceClient,
)
from google.ads.googleads.v8.services.services.recommendation_service.transports import (
    RecommendationServiceGrpcTransport as RecommendationServiceGrpcTransport,
    RecommendationServiceTransport as RecommendationServiceTransport,
)
from google.ads.googleads.v8.services.services.remarketing_action_service import (
    RemarketingActionServiceClient as RemarketingActionServiceClient,
)
from google.ads.googleads.v8.services.services.remarketing_action_service.transports import (
    RemarketingActionServiceGrpcTransport as RemarketingActionServiceGrpcTransport,
    RemarketingActionServiceTransport as RemarketingActionServiceTransport,
)
from google.ads.googleads.v8.services.services.search_term_view_service import (
    SearchTermViewServiceClient as SearchTermViewServiceClient,
)
from google.ads.googleads.v8.services.services.search_term_view_service.transports import (
    SearchTermViewServiceGrpcTransport as SearchTermViewServiceGrpcTransport,
    SearchTermViewServiceTransport as SearchTermViewServiceTransport,
)
from google.ads.googleads.v8.services.services.shared_criterion_service import (
    SharedCriterionServiceClient as SharedCriterionServiceClient,
)
from google.ads.googleads.v8.services.services.shared_criterion_service.transports import (
    SharedCriterionServiceGrpcTransport as SharedCriterionServiceGrpcTransport,
    SharedCriterionServiceTransport as SharedCriterionServiceTransport,
)
from google.ads.googleads.v8.services.services.shared_set_service import (
    SharedSetServiceClient as SharedSetServiceClient,
)
from google.ads.googleads.v8.services.services.shared_set_service.transports import (
    SharedSetServiceGrpcTransport as SharedSetServiceGrpcTransport,
    SharedSetServiceTransport as SharedSetServiceTransport,
)
from google.ads.googleads.v8.services.services.shopping_performance_view_service import (
    ShoppingPerformanceViewServiceClient as ShoppingPerformanceViewServiceClient,
)
from google.ads.googleads.v8.services.services.shopping_performance_view_service.transports import (
    ShoppingPerformanceViewServiceGrpcTransport as ShoppingPerformanceViewServiceGrpcTransport,
    ShoppingPerformanceViewServiceTransport as ShoppingPerformanceViewServiceTransport,
)
from google.ads.googleads.v8.services.services.smart_campaign_search_term_view_service import (
    SmartCampaignSearchTermViewServiceClient as SmartCampaignSearchTermViewServiceClient,
)
from google.ads.googleads.v8.services.services.smart_campaign_search_term_view_service.transports import (
    SmartCampaignSearchTermViewServiceGrpcTransport as SmartCampaignSearchTermViewServiceGrpcTransport,
    SmartCampaignSearchTermViewServiceTransport as SmartCampaignSearchTermViewServiceTransport,
)
from google.ads.googleads.v8.services.services.smart_campaign_setting_service import (
    SmartCampaignSettingServiceClient as SmartCampaignSettingServiceClient,
)
from google.ads.googleads.v8.services.services.smart_campaign_setting_service.transports import (
    SmartCampaignSettingServiceGrpcTransport as SmartCampaignSettingServiceGrpcTransport,
    SmartCampaignSettingServiceTransport as SmartCampaignSettingServiceTransport,
)
from google.ads.googleads.v8.services.services.smart_campaign_suggest_service import (
    SmartCampaignSuggestServiceClient as SmartCampaignSuggestServiceClient,
)
from google.ads.googleads.v8.services.services.smart_campaign_suggest_service.transports import (
    SmartCampaignSuggestServiceGrpcTransport as SmartCampaignSuggestServiceGrpcTransport,
    SmartCampaignSuggestServiceTransport as SmartCampaignSuggestServiceTransport,
)
from google.ads.googleads.v8.services.services.third_party_app_analytics_link_service import (
    ThirdPartyAppAnalyticsLinkServiceClient as ThirdPartyAppAnalyticsLinkServiceClient,
)
from google.ads.googleads.v8.services.services.third_party_app_analytics_link_service.transports import (
    ThirdPartyAppAnalyticsLinkServiceGrpcTransport as ThirdPartyAppAnalyticsLinkServiceGrpcTransport,
    ThirdPartyAppAnalyticsLinkServiceTransport as ThirdPartyAppAnalyticsLinkServiceTransport,
)
from google.ads.googleads.v8.services.services.topic_constant_service import (
    TopicConstantServiceClient as TopicConstantServiceClient,
)
from google.ads.googleads.v8.services.services.topic_constant_service.transports import (
    TopicConstantServiceGrpcTransport as TopicConstantServiceGrpcTransport,
    TopicConstantServiceTransport as TopicConstantServiceTransport,
)
from google.ads.googleads.v8.services.services.topic_view_service import (
    TopicViewServiceClient as TopicViewServiceClient,
)
from google.ads.googleads.v8.services.services.topic_view_service.transports import (
    TopicViewServiceGrpcTransport as TopicViewServiceGrpcTransport,
    TopicViewServiceTransport as TopicViewServiceTransport,
)
from google.ads.googleads.v8.services.services.user_data_service import (
    UserDataServiceClient as UserDataServiceClient,
)
from google.ads.googleads.v8.services.services.user_data_service.transports import (
    UserDataServiceGrpcTransport as UserDataServiceGrpcTransport,
    UserDataServiceTransport as UserDataServiceTransport,
)
from google.ads.googleads.v8.services.services.user_interest_service import (
    UserInterestServiceClient as UserInterestServiceClient,
)
from google.ads.googleads.v8.services.services.user_interest_service.transports import (
    UserInterestServiceGrpcTransport as UserInterestServiceGrpcTransport,
    UserInterestServiceTransport as UserInterestServiceTransport,
)
from google.ads.googleads.v8.services.services.user_list_service import (
    UserListServiceClient as UserListServiceClient,
)
from google.ads.googleads.v8.services.services.user_list_service.transports import (
    UserListServiceGrpcTransport as UserListServiceGrpcTransport,
    UserListServiceTransport as UserListServiceTransport,
)
from google.ads.googleads.v8.services.services.user_location_view_service import (
    UserLocationViewServiceClient as UserLocationViewServiceClient,
)
from google.ads.googleads.v8.services.services.user_location_view_service.transports import (
    UserLocationViewServiceGrpcTransport as UserLocationViewServiceGrpcTransport,
    UserLocationViewServiceTransport as UserLocationViewServiceTransport,
)
from google.ads.googleads.v8.services.services.video_service import (
    VideoServiceClient as VideoServiceClient,
)
from google.ads.googleads.v8.services.services.video_service.transports import (
    VideoServiceGrpcTransport as VideoServiceGrpcTransport,
    VideoServiceTransport as VideoServiceTransport,
)
from google.ads.googleads.v8.services.services.webpage_view_service import (
    WebpageViewServiceClient as WebpageViewServiceClient,
)
from google.ads.googleads.v8.services.services.webpage_view_service.transports import (
    WebpageViewServiceGrpcTransport as WebpageViewServiceGrpcTransport,
    WebpageViewServiceTransport as WebpageViewServiceTransport,
)
from google.ads.googleads.v8.services.types.accessible_bidding_strategy_service import (
    GetAccessibleBiddingStrategyRequest as GetAccessibleBiddingStrategyRequest,
)
from google.ads.googleads.v8.services.types.account_budget_proposal_service import (
    AccountBudgetProposalOperation as AccountBudgetProposalOperation,
    GetAccountBudgetProposalRequest as GetAccountBudgetProposalRequest,
    MutateAccountBudgetProposalRequest as MutateAccountBudgetProposalRequest,
    MutateAccountBudgetProposalResponse as MutateAccountBudgetProposalResponse,
    MutateAccountBudgetProposalResult as MutateAccountBudgetProposalResult,
)
from google.ads.googleads.v8.services.types.account_budget_service import (
    GetAccountBudgetRequest as GetAccountBudgetRequest,
)
from google.ads.googleads.v8.services.types.account_link_service import (
    AccountLinkOperation as AccountLinkOperation,
    CreateAccountLinkRequest as CreateAccountLinkRequest,
    CreateAccountLinkResponse as CreateAccountLinkResponse,
    GetAccountLinkRequest as GetAccountLinkRequest,
    MutateAccountLinkRequest as MutateAccountLinkRequest,
    MutateAccountLinkResponse as MutateAccountLinkResponse,
    MutateAccountLinkResult as MutateAccountLinkResult,
)
from google.ads.googleads.v8.services.types.ad_group_ad_asset_view_service import (
    GetAdGroupAdAssetViewRequest as GetAdGroupAdAssetViewRequest,
)
from google.ads.googleads.v8.services.types.ad_group_ad_label_service import (
    AdGroupAdLabelOperation as AdGroupAdLabelOperation,
    GetAdGroupAdLabelRequest as GetAdGroupAdLabelRequest,
    MutateAdGroupAdLabelResult as MutateAdGroupAdLabelResult,
    MutateAdGroupAdLabelsRequest as MutateAdGroupAdLabelsRequest,
    MutateAdGroupAdLabelsResponse as MutateAdGroupAdLabelsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_ad_service import (
    AdGroupAdOperation as AdGroupAdOperation,
    GetAdGroupAdRequest as GetAdGroupAdRequest,
    MutateAdGroupAdResult as MutateAdGroupAdResult,
    MutateAdGroupAdsRequest as MutateAdGroupAdsRequest,
    MutateAdGroupAdsResponse as MutateAdGroupAdsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_asset_service import (
    AdGroupAssetOperation as AdGroupAssetOperation,
    GetAdGroupAssetRequest as GetAdGroupAssetRequest,
    MutateAdGroupAssetResult as MutateAdGroupAssetResult,
    MutateAdGroupAssetsRequest as MutateAdGroupAssetsRequest,
    MutateAdGroupAssetsResponse as MutateAdGroupAssetsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_audience_view_service import (
    GetAdGroupAudienceViewRequest as GetAdGroupAudienceViewRequest,
)
from google.ads.googleads.v8.services.types.ad_group_bid_modifier_service import (
    AdGroupBidModifierOperation as AdGroupBidModifierOperation,
    GetAdGroupBidModifierRequest as GetAdGroupBidModifierRequest,
    MutateAdGroupBidModifierResult as MutateAdGroupBidModifierResult,
    MutateAdGroupBidModifiersRequest as MutateAdGroupBidModifiersRequest,
    MutateAdGroupBidModifiersResponse as MutateAdGroupBidModifiersResponse,
)
from google.ads.googleads.v8.services.types.ad_group_criterion_label_service import (
    AdGroupCriterionLabelOperation as AdGroupCriterionLabelOperation,
    GetAdGroupCriterionLabelRequest as GetAdGroupCriterionLabelRequest,
    MutateAdGroupCriterionLabelResult as MutateAdGroupCriterionLabelResult,
    MutateAdGroupCriterionLabelsRequest as MutateAdGroupCriterionLabelsRequest,
    MutateAdGroupCriterionLabelsResponse as MutateAdGroupCriterionLabelsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_criterion_service import (
    AdGroupCriterionOperation as AdGroupCriterionOperation,
    GetAdGroupCriterionRequest as GetAdGroupCriterionRequest,
    MutateAdGroupCriteriaRequest as MutateAdGroupCriteriaRequest,
    MutateAdGroupCriteriaResponse as MutateAdGroupCriteriaResponse,
    MutateAdGroupCriterionResult as MutateAdGroupCriterionResult,
)
from google.ads.googleads.v8.services.types.ad_group_criterion_simulation_service import (
    GetAdGroupCriterionSimulationRequest as GetAdGroupCriterionSimulationRequest,
)
from google.ads.googleads.v8.services.types.ad_group_extension_setting_service import (
    AdGroupExtensionSettingOperation as AdGroupExtensionSettingOperation,
    GetAdGroupExtensionSettingRequest as GetAdGroupExtensionSettingRequest,
    MutateAdGroupExtensionSettingResult as MutateAdGroupExtensionSettingResult,
    MutateAdGroupExtensionSettingsRequest as MutateAdGroupExtensionSettingsRequest,
    MutateAdGroupExtensionSettingsResponse as MutateAdGroupExtensionSettingsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_feed_service import (
    AdGroupFeedOperation as AdGroupFeedOperation,
    GetAdGroupFeedRequest as GetAdGroupFeedRequest,
    MutateAdGroupFeedResult as MutateAdGroupFeedResult,
    MutateAdGroupFeedsRequest as MutateAdGroupFeedsRequest,
    MutateAdGroupFeedsResponse as MutateAdGroupFeedsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_label_service import (
    AdGroupLabelOperation as AdGroupLabelOperation,
    GetAdGroupLabelRequest as GetAdGroupLabelRequest,
    MutateAdGroupLabelResult as MutateAdGroupLabelResult,
    MutateAdGroupLabelsRequest as MutateAdGroupLabelsRequest,
    MutateAdGroupLabelsResponse as MutateAdGroupLabelsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_service import (
    AdGroupOperation as AdGroupOperation,
    GetAdGroupRequest as GetAdGroupRequest,
    MutateAdGroupResult as MutateAdGroupResult,
    MutateAdGroupsRequest as MutateAdGroupsRequest,
    MutateAdGroupsResponse as MutateAdGroupsResponse,
)
from google.ads.googleads.v8.services.types.ad_group_simulation_service import (
    GetAdGroupSimulationRequest as GetAdGroupSimulationRequest,
)
from google.ads.googleads.v8.services.types.ad_parameter_service import (
    AdParameterOperation as AdParameterOperation,
    GetAdParameterRequest as GetAdParameterRequest,
    MutateAdParameterResult as MutateAdParameterResult,
    MutateAdParametersRequest as MutateAdParametersRequest,
    MutateAdParametersResponse as MutateAdParametersResponse,
)
from google.ads.googleads.v8.services.types.ad_schedule_view_service import (
    GetAdScheduleViewRequest as GetAdScheduleViewRequest,
)
from google.ads.googleads.v8.services.types.ad_service import (
    AdOperation as AdOperation,
    GetAdRequest as GetAdRequest,
    MutateAdResult as MutateAdResult,
    MutateAdsRequest as MutateAdsRequest,
    MutateAdsResponse as MutateAdsResponse,
)
from google.ads.googleads.v8.services.types.age_range_view_service import (
    GetAgeRangeViewRequest as GetAgeRangeViewRequest,
)
from google.ads.googleads.v8.services.types.asset_field_type_view_service import (
    GetAssetFieldTypeViewRequest as GetAssetFieldTypeViewRequest,
)
from google.ads.googleads.v8.services.types.asset_service import (
    AssetOperation as AssetOperation,
    GetAssetRequest as GetAssetRequest,
    MutateAssetResult as MutateAssetResult,
    MutateAssetsRequest as MutateAssetsRequest,
    MutateAssetsResponse as MutateAssetsResponse,
)
from google.ads.googleads.v8.services.types.batch_job_service import (
    AddBatchJobOperationsRequest as AddBatchJobOperationsRequest,
    AddBatchJobOperationsResponse as AddBatchJobOperationsResponse,
    BatchJobOperation as BatchJobOperation,
    BatchJobResult as BatchJobResult,
    GetBatchJobRequest as GetBatchJobRequest,
    ListBatchJobResultsRequest as ListBatchJobResultsRequest,
    ListBatchJobResultsResponse as ListBatchJobResultsResponse,
    MutateBatchJobRequest as MutateBatchJobRequest,
    MutateBatchJobResponse as MutateBatchJobResponse,
    MutateBatchJobResult as MutateBatchJobResult,
    RunBatchJobRequest as RunBatchJobRequest,
)
from google.ads.googleads.v8.services.types.bidding_data_exclusion_service import (
    BiddingDataExclusionOperation as BiddingDataExclusionOperation,
    GetBiddingDataExclusionRequest as GetBiddingDataExclusionRequest,
    MutateBiddingDataExclusionsRequest as MutateBiddingDataExclusionsRequest,
    MutateBiddingDataExclusionsResponse as MutateBiddingDataExclusionsResponse,
    MutateBiddingDataExclusionsResult as MutateBiddingDataExclusionsResult,
)
from google.ads.googleads.v8.services.types.bidding_seasonality_adjustment_service import (
    BiddingSeasonalityAdjustmentOperation as BiddingSeasonalityAdjustmentOperation,
    GetBiddingSeasonalityAdjustmentRequest as GetBiddingSeasonalityAdjustmentRequest,
    MutateBiddingSeasonalityAdjustmentsRequest as MutateBiddingSeasonalityAdjustmentsRequest,
    MutateBiddingSeasonalityAdjustmentsResponse as MutateBiddingSeasonalityAdjustmentsResponse,
    MutateBiddingSeasonalityAdjustmentsResult as MutateBiddingSeasonalityAdjustmentsResult,
)
from google.ads.googleads.v8.services.types.bidding_strategy_service import (
    BiddingStrategyOperation as BiddingStrategyOperation,
    GetBiddingStrategyRequest as GetBiddingStrategyRequest,
    MutateBiddingStrategiesRequest as MutateBiddingStrategiesRequest,
    MutateBiddingStrategiesResponse as MutateBiddingStrategiesResponse,
    MutateBiddingStrategyResult as MutateBiddingStrategyResult,
)
from google.ads.googleads.v8.services.types.bidding_strategy_simulation_service import (
    GetBiddingStrategySimulationRequest as GetBiddingStrategySimulationRequest,
)
from google.ads.googleads.v8.services.types.billing_setup_service import (
    BillingSetupOperation as BillingSetupOperation,
    GetBillingSetupRequest as GetBillingSetupRequest,
    MutateBillingSetupRequest as MutateBillingSetupRequest,
    MutateBillingSetupResponse as MutateBillingSetupResponse,
    MutateBillingSetupResult as MutateBillingSetupResult,
)
from google.ads.googleads.v8.services.types.campaign_asset_service import (
    CampaignAssetOperation as CampaignAssetOperation,
    GetCampaignAssetRequest as GetCampaignAssetRequest,
    MutateCampaignAssetResult as MutateCampaignAssetResult,
    MutateCampaignAssetsRequest as MutateCampaignAssetsRequest,
    MutateCampaignAssetsResponse as MutateCampaignAssetsResponse,
)
from google.ads.googleads.v8.services.types.campaign_audience_view_service import (
    GetCampaignAudienceViewRequest as GetCampaignAudienceViewRequest,
)
from google.ads.googleads.v8.services.types.campaign_bid_modifier_service import (
    CampaignBidModifierOperation as CampaignBidModifierOperation,
    GetCampaignBidModifierRequest as GetCampaignBidModifierRequest,
    MutateCampaignBidModifierResult as MutateCampaignBidModifierResult,
    MutateCampaignBidModifiersRequest as MutateCampaignBidModifiersRequest,
    MutateCampaignBidModifiersResponse as MutateCampaignBidModifiersResponse,
)
from google.ads.googleads.v8.services.types.campaign_budget_service import (
    CampaignBudgetOperation as CampaignBudgetOperation,
    GetCampaignBudgetRequest as GetCampaignBudgetRequest,
    MutateCampaignBudgetResult as MutateCampaignBudgetResult,
    MutateCampaignBudgetsRequest as MutateCampaignBudgetsRequest,
    MutateCampaignBudgetsResponse as MutateCampaignBudgetsResponse,
)
from google.ads.googleads.v8.services.types.campaign_criterion_service import (
    CampaignCriterionOperation as CampaignCriterionOperation,
    GetCampaignCriterionRequest as GetCampaignCriterionRequest,
    MutateCampaignCriteriaRequest as MutateCampaignCriteriaRequest,
    MutateCampaignCriteriaResponse as MutateCampaignCriteriaResponse,
    MutateCampaignCriterionResult as MutateCampaignCriterionResult,
)
from google.ads.googleads.v8.services.types.campaign_criterion_simulation_service import (
    GetCampaignCriterionSimulationRequest as GetCampaignCriterionSimulationRequest,
)
from google.ads.googleads.v8.services.types.campaign_draft_service import (
    CampaignDraftOperation as CampaignDraftOperation,
    GetCampaignDraftRequest as GetCampaignDraftRequest,
    ListCampaignDraftAsyncErrorsRequest as ListCampaignDraftAsyncErrorsRequest,
    ListCampaignDraftAsyncErrorsResponse as ListCampaignDraftAsyncErrorsResponse,
    MutateCampaignDraftResult as MutateCampaignDraftResult,
    MutateCampaignDraftsRequest as MutateCampaignDraftsRequest,
    MutateCampaignDraftsResponse as MutateCampaignDraftsResponse,
    PromoteCampaignDraftRequest as PromoteCampaignDraftRequest,
)
from google.ads.googleads.v8.services.types.campaign_experiment_service import (
    CampaignExperimentOperation as CampaignExperimentOperation,
    CreateCampaignExperimentMetadata as CreateCampaignExperimentMetadata,
    CreateCampaignExperimentRequest as CreateCampaignExperimentRequest,
    EndCampaignExperimentRequest as EndCampaignExperimentRequest,
    GetCampaignExperimentRequest as GetCampaignExperimentRequest,
    GraduateCampaignExperimentRequest as GraduateCampaignExperimentRequest,
    GraduateCampaignExperimentResponse as GraduateCampaignExperimentResponse,
    ListCampaignExperimentAsyncErrorsRequest as ListCampaignExperimentAsyncErrorsRequest,
    ListCampaignExperimentAsyncErrorsResponse as ListCampaignExperimentAsyncErrorsResponse,
    MutateCampaignExperimentResult as MutateCampaignExperimentResult,
    MutateCampaignExperimentsRequest as MutateCampaignExperimentsRequest,
    MutateCampaignExperimentsResponse as MutateCampaignExperimentsResponse,
    PromoteCampaignExperimentRequest as PromoteCampaignExperimentRequest,
)
from google.ads.googleads.v8.services.types.campaign_extension_setting_service import (
    CampaignExtensionSettingOperation as CampaignExtensionSettingOperation,
    GetCampaignExtensionSettingRequest as GetCampaignExtensionSettingRequest,
    MutateCampaignExtensionSettingResult as MutateCampaignExtensionSettingResult,
    MutateCampaignExtensionSettingsRequest as MutateCampaignExtensionSettingsRequest,
    MutateCampaignExtensionSettingsResponse as MutateCampaignExtensionSettingsResponse,
)
from google.ads.googleads.v8.services.types.campaign_feed_service import (
    CampaignFeedOperation as CampaignFeedOperation,
    GetCampaignFeedRequest as GetCampaignFeedRequest,
    MutateCampaignFeedResult as MutateCampaignFeedResult,
    MutateCampaignFeedsRequest as MutateCampaignFeedsRequest,
    MutateCampaignFeedsResponse as MutateCampaignFeedsResponse,
)
from google.ads.googleads.v8.services.types.campaign_label_service import (
    CampaignLabelOperation as CampaignLabelOperation,
    GetCampaignLabelRequest as GetCampaignLabelRequest,
    MutateCampaignLabelResult as MutateCampaignLabelResult,
    MutateCampaignLabelsRequest as MutateCampaignLabelsRequest,
    MutateCampaignLabelsResponse as MutateCampaignLabelsResponse,
)
from google.ads.googleads.v8.services.types.campaign_service import (
    CampaignOperation as CampaignOperation,
    GetCampaignRequest as GetCampaignRequest,
    MutateCampaignResult as MutateCampaignResult,
    MutateCampaignsRequest as MutateCampaignsRequest,
    MutateCampaignsResponse as MutateCampaignsResponse,
)
from google.ads.googleads.v8.services.types.campaign_shared_set_service import (
    CampaignSharedSetOperation as CampaignSharedSetOperation,
    GetCampaignSharedSetRequest as GetCampaignSharedSetRequest,
    MutateCampaignSharedSetResult as MutateCampaignSharedSetResult,
    MutateCampaignSharedSetsRequest as MutateCampaignSharedSetsRequest,
    MutateCampaignSharedSetsResponse as MutateCampaignSharedSetsResponse,
)
from google.ads.googleads.v8.services.types.campaign_simulation_service import (
    GetCampaignSimulationRequest as GetCampaignSimulationRequest,
)
from google.ads.googleads.v8.services.types.carrier_constant_service import (
    GetCarrierConstantRequest as GetCarrierConstantRequest,
)
from google.ads.googleads.v8.services.types.change_status_service import (
    GetChangeStatusRequest as GetChangeStatusRequest,
)
from google.ads.googleads.v8.services.types.click_view_service import (
    GetClickViewRequest as GetClickViewRequest,
)
from google.ads.googleads.v8.services.types.combined_audience_service import (
    GetCombinedAudienceRequest as GetCombinedAudienceRequest,
)
from google.ads.googleads.v8.services.types.conversion_action_service import (
    ConversionActionOperation as ConversionActionOperation,
    GetConversionActionRequest as GetConversionActionRequest,
    MutateConversionActionResult as MutateConversionActionResult,
    MutateConversionActionsRequest as MutateConversionActionsRequest,
    MutateConversionActionsResponse as MutateConversionActionsResponse,
)
from google.ads.googleads.v8.services.types.conversion_adjustment_upload_service import (
    ConversionAdjustment as ConversionAdjustment,
    ConversionAdjustmentResult as ConversionAdjustmentResult,
    GclidDateTimePair as GclidDateTimePair,
    RestatementValue as RestatementValue,
    UploadConversionAdjustmentsRequest as UploadConversionAdjustmentsRequest,
    UploadConversionAdjustmentsResponse as UploadConversionAdjustmentsResponse,
)
from google.ads.googleads.v8.services.types.conversion_custom_variable_service import (
    ConversionCustomVariableOperation as ConversionCustomVariableOperation,
    GetConversionCustomVariableRequest as GetConversionCustomVariableRequest,
    MutateConversionCustomVariableResult as MutateConversionCustomVariableResult,
    MutateConversionCustomVariablesRequest as MutateConversionCustomVariablesRequest,
    MutateConversionCustomVariablesResponse as MutateConversionCustomVariablesResponse,
)
from google.ads.googleads.v8.services.types.conversion_upload_service import (
    CallConversion as CallConversion,
    CallConversionResult as CallConversionResult,
    CartData as CartData,
    ClickConversion as ClickConversion,
    ClickConversionResult as ClickConversionResult,
    CustomVariable as CustomVariable,
    ExternalAttributionData as ExternalAttributionData,
    UploadCallConversionsRequest as UploadCallConversionsRequest,
    UploadCallConversionsResponse as UploadCallConversionsResponse,
    UploadClickConversionsRequest as UploadClickConversionsRequest,
    UploadClickConversionsResponse as UploadClickConversionsResponse,
)
from google.ads.googleads.v8.services.types.conversion_value_rule_service import (
    ConversionValueRuleOperation as ConversionValueRuleOperation,
    GetConversionValueRuleRequest as GetConversionValueRuleRequest,
    MutateConversionValueRuleResult as MutateConversionValueRuleResult,
    MutateConversionValueRulesRequest as MutateConversionValueRulesRequest,
    MutateConversionValueRulesResponse as MutateConversionValueRulesResponse,
)
from google.ads.googleads.v8.services.types.conversion_value_rule_set_service import (
    ConversionValueRuleSetOperation as ConversionValueRuleSetOperation,
    GetConversionValueRuleSetRequest as GetConversionValueRuleSetRequest,
    MutateConversionValueRuleSetResult as MutateConversionValueRuleSetResult,
    MutateConversionValueRuleSetsRequest as MutateConversionValueRuleSetsRequest,
    MutateConversionValueRuleSetsResponse as MutateConversionValueRuleSetsResponse,
)
from google.ads.googleads.v8.services.types.currency_constant_service import (
    GetCurrencyConstantRequest as GetCurrencyConstantRequest,
)
from google.ads.googleads.v8.services.types.custom_audience_service import (
    CustomAudienceOperation as CustomAudienceOperation,
    GetCustomAudienceRequest as GetCustomAudienceRequest,
    MutateCustomAudienceResult as MutateCustomAudienceResult,
    MutateCustomAudiencesRequest as MutateCustomAudiencesRequest,
    MutateCustomAudiencesResponse as MutateCustomAudiencesResponse,
)
from google.ads.googleads.v8.services.types.custom_interest_service import (
    CustomInterestOperation as CustomInterestOperation,
    GetCustomInterestRequest as GetCustomInterestRequest,
    MutateCustomInterestResult as MutateCustomInterestResult,
    MutateCustomInterestsRequest as MutateCustomInterestsRequest,
    MutateCustomInterestsResponse as MutateCustomInterestsResponse,
)
from google.ads.googleads.v8.services.types.customer_asset_service import (
    CustomerAssetOperation as CustomerAssetOperation,
    GetCustomerAssetRequest as GetCustomerAssetRequest,
    MutateCustomerAssetResult as MutateCustomerAssetResult,
    MutateCustomerAssetsRequest as MutateCustomerAssetsRequest,
    MutateCustomerAssetsResponse as MutateCustomerAssetsResponse,
)
from google.ads.googleads.v8.services.types.customer_client_link_service import (
    CustomerClientLinkOperation as CustomerClientLinkOperation,
    GetCustomerClientLinkRequest as GetCustomerClientLinkRequest,
    MutateCustomerClientLinkRequest as MutateCustomerClientLinkRequest,
    MutateCustomerClientLinkResponse as MutateCustomerClientLinkResponse,
    MutateCustomerClientLinkResult as MutateCustomerClientLinkResult,
)
from google.ads.googleads.v8.services.types.customer_client_service import (
    GetCustomerClientRequest as GetCustomerClientRequest,
)
from google.ads.googleads.v8.services.types.customer_extension_setting_service import (
    CustomerExtensionSettingOperation as CustomerExtensionSettingOperation,
    GetCustomerExtensionSettingRequest as GetCustomerExtensionSettingRequest,
    MutateCustomerExtensionSettingResult as MutateCustomerExtensionSettingResult,
    MutateCustomerExtensionSettingsRequest as MutateCustomerExtensionSettingsRequest,
    MutateCustomerExtensionSettingsResponse as MutateCustomerExtensionSettingsResponse,
)
from google.ads.googleads.v8.services.types.customer_feed_service import (
    CustomerFeedOperation as CustomerFeedOperation,
    GetCustomerFeedRequest as GetCustomerFeedRequest,
    MutateCustomerFeedResult as MutateCustomerFeedResult,
    MutateCustomerFeedsRequest as MutateCustomerFeedsRequest,
    MutateCustomerFeedsResponse as MutateCustomerFeedsResponse,
)
from google.ads.googleads.v8.services.types.customer_label_service import (
    CustomerLabelOperation as CustomerLabelOperation,
    GetCustomerLabelRequest as GetCustomerLabelRequest,
    MutateCustomerLabelResult as MutateCustomerLabelResult,
    MutateCustomerLabelsRequest as MutateCustomerLabelsRequest,
    MutateCustomerLabelsResponse as MutateCustomerLabelsResponse,
)
from google.ads.googleads.v8.services.types.customer_manager_link_service import (
    CustomerManagerLinkOperation as CustomerManagerLinkOperation,
    GetCustomerManagerLinkRequest as GetCustomerManagerLinkRequest,
    MoveManagerLinkRequest as MoveManagerLinkRequest,
    MoveManagerLinkResponse as MoveManagerLinkResponse,
    MutateCustomerManagerLinkRequest as MutateCustomerManagerLinkRequest,
    MutateCustomerManagerLinkResponse as MutateCustomerManagerLinkResponse,
    MutateCustomerManagerLinkResult as MutateCustomerManagerLinkResult,
)
from google.ads.googleads.v8.services.types.customer_negative_criterion_service import (
    CustomerNegativeCriterionOperation as CustomerNegativeCriterionOperation,
    GetCustomerNegativeCriterionRequest as GetCustomerNegativeCriterionRequest,
    MutateCustomerNegativeCriteriaRequest as MutateCustomerNegativeCriteriaRequest,
    MutateCustomerNegativeCriteriaResponse as MutateCustomerNegativeCriteriaResponse,
    MutateCustomerNegativeCriteriaResult as MutateCustomerNegativeCriteriaResult,
)
from google.ads.googleads.v8.services.types.customer_service import (
    CreateCustomerClientRequest as CreateCustomerClientRequest,
    CreateCustomerClientResponse as CreateCustomerClientResponse,
    CustomerOperation as CustomerOperation,
    GetCustomerRequest as GetCustomerRequest,
    ListAccessibleCustomersRequest as ListAccessibleCustomersRequest,
    ListAccessibleCustomersResponse as ListAccessibleCustomersResponse,
    MutateCustomerRequest as MutateCustomerRequest,
    MutateCustomerResponse as MutateCustomerResponse,
    MutateCustomerResult as MutateCustomerResult,
)
from google.ads.googleads.v8.services.types.customer_user_access_invitation_service import (
    CustomerUserAccessInvitationOperation as CustomerUserAccessInvitationOperation,
    GetCustomerUserAccessInvitationRequest as GetCustomerUserAccessInvitationRequest,
    MutateCustomerUserAccessInvitationRequest as MutateCustomerUserAccessInvitationRequest,
    MutateCustomerUserAccessInvitationResponse as MutateCustomerUserAccessInvitationResponse,
    MutateCustomerUserAccessInvitationResult as MutateCustomerUserAccessInvitationResult,
)
from google.ads.googleads.v8.services.types.customer_user_access_service import (
    CustomerUserAccessOperation as CustomerUserAccessOperation,
    GetCustomerUserAccessRequest as GetCustomerUserAccessRequest,
    MutateCustomerUserAccessRequest as MutateCustomerUserAccessRequest,
    MutateCustomerUserAccessResponse as MutateCustomerUserAccessResponse,
    MutateCustomerUserAccessResult as MutateCustomerUserAccessResult,
)
from google.ads.googleads.v8.services.types.detail_placement_view_service import (
    GetDetailPlacementViewRequest as GetDetailPlacementViewRequest,
)
from google.ads.googleads.v8.services.types.detailed_demographic_service import (
    GetDetailedDemographicRequest as GetDetailedDemographicRequest,
)
from google.ads.googleads.v8.services.types.display_keyword_view_service import (
    GetDisplayKeywordViewRequest as GetDisplayKeywordViewRequest,
)
from google.ads.googleads.v8.services.types.distance_view_service import (
    GetDistanceViewRequest as GetDistanceViewRequest,
)
from google.ads.googleads.v8.services.types.domain_category_service import (
    GetDomainCategoryRequest as GetDomainCategoryRequest,
)
from google.ads.googleads.v8.services.types.dynamic_search_ads_search_term_view_service import (
    GetDynamicSearchAdsSearchTermViewRequest as GetDynamicSearchAdsSearchTermViewRequest,
)
from google.ads.googleads.v8.services.types.expanded_landing_page_view_service import (
    GetExpandedLandingPageViewRequest as GetExpandedLandingPageViewRequest,
)
from google.ads.googleads.v8.services.types.extension_feed_item_service import (
    ExtensionFeedItemOperation as ExtensionFeedItemOperation,
    GetExtensionFeedItemRequest as GetExtensionFeedItemRequest,
    MutateExtensionFeedItemResult as MutateExtensionFeedItemResult,
    MutateExtensionFeedItemsRequest as MutateExtensionFeedItemsRequest,
    MutateExtensionFeedItemsResponse as MutateExtensionFeedItemsResponse,
)
from google.ads.googleads.v8.services.types.feed_item_service import (
    FeedItemOperation as FeedItemOperation,
    GetFeedItemRequest as GetFeedItemRequest,
    MutateFeedItemResult as MutateFeedItemResult,
    MutateFeedItemsRequest as MutateFeedItemsRequest,
    MutateFeedItemsResponse as MutateFeedItemsResponse,
)
from google.ads.googleads.v8.services.types.feed_item_set_link_service import (
    FeedItemSetLinkOperation as FeedItemSetLinkOperation,
    GetFeedItemSetLinkRequest as GetFeedItemSetLinkRequest,
    MutateFeedItemSetLinkResult as MutateFeedItemSetLinkResult,
    MutateFeedItemSetLinksRequest as MutateFeedItemSetLinksRequest,
    MutateFeedItemSetLinksResponse as MutateFeedItemSetLinksResponse,
)
from google.ads.googleads.v8.services.types.feed_item_set_service import (
    FeedItemSetOperation as FeedItemSetOperation,
    GetFeedItemSetRequest as GetFeedItemSetRequest,
    MutateFeedItemSetResult as MutateFeedItemSetResult,
    MutateFeedItemSetsRequest as MutateFeedItemSetsRequest,
    MutateFeedItemSetsResponse as MutateFeedItemSetsResponse,
)
from google.ads.googleads.v8.services.types.feed_item_target_service import (
    FeedItemTargetOperation as FeedItemTargetOperation,
    GetFeedItemTargetRequest as GetFeedItemTargetRequest,
    MutateFeedItemTargetResult as MutateFeedItemTargetResult,
    MutateFeedItemTargetsRequest as MutateFeedItemTargetsRequest,
    MutateFeedItemTargetsResponse as MutateFeedItemTargetsResponse,
)
from google.ads.googleads.v8.services.types.feed_mapping_service import (
    FeedMappingOperation as FeedMappingOperation,
    GetFeedMappingRequest as GetFeedMappingRequest,
    MutateFeedMappingResult as MutateFeedMappingResult,
    MutateFeedMappingsRequest as MutateFeedMappingsRequest,
    MutateFeedMappingsResponse as MutateFeedMappingsResponse,
)
from google.ads.googleads.v8.services.types.feed_placeholder_view_service import (
    GetFeedPlaceholderViewRequest as GetFeedPlaceholderViewRequest,
)
from google.ads.googleads.v8.services.types.feed_service import (
    FeedOperation as FeedOperation,
    GetFeedRequest as GetFeedRequest,
    MutateFeedResult as MutateFeedResult,
    MutateFeedsRequest as MutateFeedsRequest,
    MutateFeedsResponse as MutateFeedsResponse,
)
from google.ads.googleads.v8.services.types.gender_view_service import (
    GetGenderViewRequest as GetGenderViewRequest,
)
from google.ads.googleads.v8.services.types.geo_target_constant_service import (
    GeoTargetConstantSuggestion as GeoTargetConstantSuggestion,
    GetGeoTargetConstantRequest as GetGeoTargetConstantRequest,
    SuggestGeoTargetConstantsRequest as SuggestGeoTargetConstantsRequest,
    SuggestGeoTargetConstantsResponse as SuggestGeoTargetConstantsResponse,
)
from google.ads.googleads.v8.services.types.geographic_view_service import (
    GetGeographicViewRequest as GetGeographicViewRequest,
)
from google.ads.googleads.v8.services.types.google_ads_field_service import (
    GetGoogleAdsFieldRequest as GetGoogleAdsFieldRequest,
    SearchGoogleAdsFieldsRequest as SearchGoogleAdsFieldsRequest,
    SearchGoogleAdsFieldsResponse as SearchGoogleAdsFieldsResponse,
)
from google.ads.googleads.v8.services.types.google_ads_service import (
    GoogleAdsRow as GoogleAdsRow,
    MutateGoogleAdsRequest as MutateGoogleAdsRequest,
    MutateGoogleAdsResponse as MutateGoogleAdsResponse,
    MutateOperation as MutateOperation,
    MutateOperationResponse as MutateOperationResponse,
    SearchGoogleAdsRequest as SearchGoogleAdsRequest,
    SearchGoogleAdsResponse as SearchGoogleAdsResponse,
    SearchGoogleAdsStreamRequest as SearchGoogleAdsStreamRequest,
    SearchGoogleAdsStreamResponse as SearchGoogleAdsStreamResponse,
)
from google.ads.googleads.v8.services.types.group_placement_view_service import (
    GetGroupPlacementViewRequest as GetGroupPlacementViewRequest,
)
from google.ads.googleads.v8.services.types.hotel_group_view_service import (
    GetHotelGroupViewRequest as GetHotelGroupViewRequest,
)
from google.ads.googleads.v8.services.types.hotel_performance_view_service import (
    GetHotelPerformanceViewRequest as GetHotelPerformanceViewRequest,
)
from google.ads.googleads.v8.services.types.income_range_view_service import (
    GetIncomeRangeViewRequest as GetIncomeRangeViewRequest,
)
from google.ads.googleads.v8.services.types.invoice_service import (
    ListInvoicesRequest as ListInvoicesRequest,
    ListInvoicesResponse as ListInvoicesResponse,
)
from google.ads.googleads.v8.services.types.keyword_plan_ad_group_keyword_service import (
    GetKeywordPlanAdGroupKeywordRequest as GetKeywordPlanAdGroupKeywordRequest,
    KeywordPlanAdGroupKeywordOperation as KeywordPlanAdGroupKeywordOperation,
    MutateKeywordPlanAdGroupKeywordResult as MutateKeywordPlanAdGroupKeywordResult,
    MutateKeywordPlanAdGroupKeywordsRequest as MutateKeywordPlanAdGroupKeywordsRequest,
    MutateKeywordPlanAdGroupKeywordsResponse as MutateKeywordPlanAdGroupKeywordsResponse,
)
from google.ads.googleads.v8.services.types.keyword_plan_ad_group_service import (
    GetKeywordPlanAdGroupRequest as GetKeywordPlanAdGroupRequest,
    KeywordPlanAdGroupOperation as KeywordPlanAdGroupOperation,
    MutateKeywordPlanAdGroupResult as MutateKeywordPlanAdGroupResult,
    MutateKeywordPlanAdGroupsRequest as MutateKeywordPlanAdGroupsRequest,
    MutateKeywordPlanAdGroupsResponse as MutateKeywordPlanAdGroupsResponse,
)
from google.ads.googleads.v8.services.types.keyword_plan_campaign_keyword_service import (
    GetKeywordPlanCampaignKeywordRequest as GetKeywordPlanCampaignKeywordRequest,
    KeywordPlanCampaignKeywordOperation as KeywordPlanCampaignKeywordOperation,
    MutateKeywordPlanCampaignKeywordResult as MutateKeywordPlanCampaignKeywordResult,
    MutateKeywordPlanCampaignKeywordsRequest as MutateKeywordPlanCampaignKeywordsRequest,
    MutateKeywordPlanCampaignKeywordsResponse as MutateKeywordPlanCampaignKeywordsResponse,
)
from google.ads.googleads.v8.services.types.keyword_plan_campaign_service import (
    GetKeywordPlanCampaignRequest as GetKeywordPlanCampaignRequest,
    KeywordPlanCampaignOperation as KeywordPlanCampaignOperation,
    MutateKeywordPlanCampaignResult as MutateKeywordPlanCampaignResult,
    MutateKeywordPlanCampaignsRequest as MutateKeywordPlanCampaignsRequest,
    MutateKeywordPlanCampaignsResponse as MutateKeywordPlanCampaignsResponse,
)
from google.ads.googleads.v8.services.types.keyword_plan_idea_service import (
    GenerateKeywordIdeaResponse as GenerateKeywordIdeaResponse,
    GenerateKeywordIdeaResult as GenerateKeywordIdeaResult,
    GenerateKeywordIdeasRequest as GenerateKeywordIdeasRequest,
    KeywordAndUrlSeed as KeywordAndUrlSeed,
    KeywordSeed as KeywordSeed,
    SiteSeed as SiteSeed,
    UrlSeed as UrlSeed,
)
from google.ads.googleads.v8.services.types.keyword_plan_service import (
    ForecastMetrics as ForecastMetrics,
    GenerateForecastCurveRequest as GenerateForecastCurveRequest,
    GenerateForecastCurveResponse as GenerateForecastCurveResponse,
    GenerateForecastMetricsRequest as GenerateForecastMetricsRequest,
    GenerateForecastMetricsResponse as GenerateForecastMetricsResponse,
    GenerateForecastTimeSeriesRequest as GenerateForecastTimeSeriesRequest,
    GenerateForecastTimeSeriesResponse as GenerateForecastTimeSeriesResponse,
    GenerateHistoricalMetricsRequest as GenerateHistoricalMetricsRequest,
    GenerateHistoricalMetricsResponse as GenerateHistoricalMetricsResponse,
    GetKeywordPlanRequest as GetKeywordPlanRequest,
    KeywordPlanAdGroupForecast as KeywordPlanAdGroupForecast,
    KeywordPlanCampaignForecast as KeywordPlanCampaignForecast,
    KeywordPlanCampaignForecastCurve as KeywordPlanCampaignForecastCurve,
    KeywordPlanKeywordForecast as KeywordPlanKeywordForecast,
    KeywordPlanKeywordHistoricalMetrics as KeywordPlanKeywordHistoricalMetrics,
    KeywordPlanMaxCpcBidForecast as KeywordPlanMaxCpcBidForecast,
    KeywordPlanMaxCpcBidForecastCurve as KeywordPlanMaxCpcBidForecastCurve,
    KeywordPlanOperation as KeywordPlanOperation,
    KeywordPlanWeeklyForecast as KeywordPlanWeeklyForecast,
    KeywordPlanWeeklyTimeSeriesForecast as KeywordPlanWeeklyTimeSeriesForecast,
    MutateKeywordPlansRequest as MutateKeywordPlansRequest,
    MutateKeywordPlansResponse as MutateKeywordPlansResponse,
    MutateKeywordPlansResult as MutateKeywordPlansResult,
)
from google.ads.googleads.v8.services.types.keyword_theme_constant_service import (
    GetKeywordThemeConstantRequest as GetKeywordThemeConstantRequest,
    SuggestKeywordThemeConstantsRequest as SuggestKeywordThemeConstantsRequest,
    SuggestKeywordThemeConstantsResponse as SuggestKeywordThemeConstantsResponse,
)
from google.ads.googleads.v8.services.types.keyword_view_service import (
    GetKeywordViewRequest as GetKeywordViewRequest,
)
from google.ads.googleads.v8.services.types.label_service import (
    GetLabelRequest as GetLabelRequest,
    LabelOperation as LabelOperation,
    MutateLabelResult as MutateLabelResult,
    MutateLabelsRequest as MutateLabelsRequest,
    MutateLabelsResponse as MutateLabelsResponse,
)
from google.ads.googleads.v8.services.types.landing_page_view_service import (
    GetLandingPageViewRequest as GetLandingPageViewRequest,
)
from google.ads.googleads.v8.services.types.language_constant_service import (
    GetLanguageConstantRequest as GetLanguageConstantRequest,
)
from google.ads.googleads.v8.services.types.life_event_service import (
    GetLifeEventRequest as GetLifeEventRequest,
)
from google.ads.googleads.v8.services.types.location_view_service import (
    GetLocationViewRequest as GetLocationViewRequest,
)
from google.ads.googleads.v8.services.types.managed_placement_view_service import (
    GetManagedPlacementViewRequest as GetManagedPlacementViewRequest,
)
from google.ads.googleads.v8.services.types.media_file_service import (
    GetMediaFileRequest as GetMediaFileRequest,
    MediaFileOperation as MediaFileOperation,
    MutateMediaFileResult as MutateMediaFileResult,
    MutateMediaFilesRequest as MutateMediaFilesRequest,
    MutateMediaFilesResponse as MutateMediaFilesResponse,
)
from google.ads.googleads.v8.services.types.merchant_center_link_service import (
    GetMerchantCenterLinkRequest as GetMerchantCenterLinkRequest,
    ListMerchantCenterLinksRequest as ListMerchantCenterLinksRequest,
    ListMerchantCenterLinksResponse as ListMerchantCenterLinksResponse,
    MerchantCenterLinkOperation as MerchantCenterLinkOperation,
    MutateMerchantCenterLinkRequest as MutateMerchantCenterLinkRequest,
    MutateMerchantCenterLinkResponse as MutateMerchantCenterLinkResponse,
    MutateMerchantCenterLinkResult as MutateMerchantCenterLinkResult,
)
from google.ads.googleads.v8.services.types.mobile_app_category_constant_service import (
    GetMobileAppCategoryConstantRequest as GetMobileAppCategoryConstantRequest,
)
from google.ads.googleads.v8.services.types.mobile_device_constant_service import (
    GetMobileDeviceConstantRequest as GetMobileDeviceConstantRequest,
)
from google.ads.googleads.v8.services.types.offline_user_data_job_service import (
    AddOfflineUserDataJobOperationsRequest as AddOfflineUserDataJobOperationsRequest,
    AddOfflineUserDataJobOperationsResponse as AddOfflineUserDataJobOperationsResponse,
    CreateOfflineUserDataJobRequest as CreateOfflineUserDataJobRequest,
    CreateOfflineUserDataJobResponse as CreateOfflineUserDataJobResponse,
    GetOfflineUserDataJobRequest as GetOfflineUserDataJobRequest,
    OfflineUserDataJobOperation as OfflineUserDataJobOperation,
    RunOfflineUserDataJobRequest as RunOfflineUserDataJobRequest,
)
from google.ads.googleads.v8.services.types.operating_system_version_constant_service import (
    GetOperatingSystemVersionConstantRequest as GetOperatingSystemVersionConstantRequest,
)
from google.ads.googleads.v8.services.types.paid_organic_search_term_view_service import (
    GetPaidOrganicSearchTermViewRequest as GetPaidOrganicSearchTermViewRequest,
)
from google.ads.googleads.v8.services.types.parental_status_view_service import (
    GetParentalStatusViewRequest as GetParentalStatusViewRequest,
)
from google.ads.googleads.v8.services.types.payments_account_service import (
    ListPaymentsAccountsRequest as ListPaymentsAccountsRequest,
    ListPaymentsAccountsResponse as ListPaymentsAccountsResponse,
)
from google.ads.googleads.v8.services.types.product_bidding_category_constant_service import (
    GetProductBiddingCategoryConstantRequest as GetProductBiddingCategoryConstantRequest,
)
from google.ads.googleads.v8.services.types.product_group_view_service import (
    GetProductGroupViewRequest as GetProductGroupViewRequest,
)
from google.ads.googleads.v8.services.types.reach_plan_service import (
    CampaignDuration as CampaignDuration,
    EffectiveFrequencyBreakdown as EffectiveFrequencyBreakdown,
    EffectiveFrequencyLimit as EffectiveFrequencyLimit,
    Forecast as Forecast,
    FrequencyCap as FrequencyCap,
    GenerateProductMixIdeasRequest as GenerateProductMixIdeasRequest,
    GenerateProductMixIdeasResponse as GenerateProductMixIdeasResponse,
    GenerateReachForecastRequest as GenerateReachForecastRequest,
    GenerateReachForecastResponse as GenerateReachForecastResponse,
    ListPlannableLocationsRequest as ListPlannableLocationsRequest,
    ListPlannableLocationsResponse as ListPlannableLocationsResponse,
    ListPlannableProductsRequest as ListPlannableProductsRequest,
    ListPlannableProductsResponse as ListPlannableProductsResponse,
    OnTargetAudienceMetrics as OnTargetAudienceMetrics,
    PlannableLocation as PlannableLocation,
    PlannableTargeting as PlannableTargeting,
    PlannedProduct as PlannedProduct,
    PlannedProductForecast as PlannedProductForecast,
    PlannedProductReachForecast as PlannedProductReachForecast,
    Preferences as Preferences,
    ProductAllocation as ProductAllocation,
    ProductMetadata as ProductMetadata,
    ReachCurve as ReachCurve,
    ReachForecast as ReachForecast,
    Targeting as Targeting,
)
from google.ads.googleads.v8.services.types.recommendation_service import (
    ApplyRecommendationOperation as ApplyRecommendationOperation,
    ApplyRecommendationRequest as ApplyRecommendationRequest,
    ApplyRecommendationResponse as ApplyRecommendationResponse,
    ApplyRecommendationResult as ApplyRecommendationResult,
    DismissRecommendationRequest as DismissRecommendationRequest,
    DismissRecommendationResponse as DismissRecommendationResponse,
    GetRecommendationRequest as GetRecommendationRequest,
)
from google.ads.googleads.v8.services.types.remarketing_action_service import (
    GetRemarketingActionRequest as GetRemarketingActionRequest,
    MutateRemarketingActionResult as MutateRemarketingActionResult,
    MutateRemarketingActionsRequest as MutateRemarketingActionsRequest,
    MutateRemarketingActionsResponse as MutateRemarketingActionsResponse,
    RemarketingActionOperation as RemarketingActionOperation,
)
from google.ads.googleads.v8.services.types.search_term_view_service import (
    GetSearchTermViewRequest as GetSearchTermViewRequest,
)
from google.ads.googleads.v8.services.types.shared_criterion_service import (
    GetSharedCriterionRequest as GetSharedCriterionRequest,
    MutateSharedCriteriaRequest as MutateSharedCriteriaRequest,
    MutateSharedCriteriaResponse as MutateSharedCriteriaResponse,
    MutateSharedCriterionResult as MutateSharedCriterionResult,
    SharedCriterionOperation as SharedCriterionOperation,
)
from google.ads.googleads.v8.services.types.shared_set_service import (
    GetSharedSetRequest as GetSharedSetRequest,
    MutateSharedSetResult as MutateSharedSetResult,
    MutateSharedSetsRequest as MutateSharedSetsRequest,
    MutateSharedSetsResponse as MutateSharedSetsResponse,
    SharedSetOperation as SharedSetOperation,
)
from google.ads.googleads.v8.services.types.shopping_performance_view_service import (
    GetShoppingPerformanceViewRequest as GetShoppingPerformanceViewRequest,
)
from google.ads.googleads.v8.services.types.smart_campaign_search_term_view_service import (
    GetSmartCampaignSearchTermViewRequest as GetSmartCampaignSearchTermViewRequest,
)
from google.ads.googleads.v8.services.types.smart_campaign_setting_service import (
    GetSmartCampaignSettingRequest as GetSmartCampaignSettingRequest,
    MutateSmartCampaignSettingResult as MutateSmartCampaignSettingResult,
    MutateSmartCampaignSettingsRequest as MutateSmartCampaignSettingsRequest,
    MutateSmartCampaignSettingsResponse as MutateSmartCampaignSettingsResponse,
    SmartCampaignSettingOperation as SmartCampaignSettingOperation,
)
from google.ads.googleads.v8.services.types.smart_campaign_suggest_service import (
    SmartCampaignSuggestionInfo as SmartCampaignSuggestionInfo,
    SuggestSmartCampaignAdRequest as SuggestSmartCampaignAdRequest,
    SuggestSmartCampaignAdResponse as SuggestSmartCampaignAdResponse,
    SuggestSmartCampaignBudgetOptionsRequest as SuggestSmartCampaignBudgetOptionsRequest,
    SuggestSmartCampaignBudgetOptionsResponse as SuggestSmartCampaignBudgetOptionsResponse,
)
from google.ads.googleads.v8.services.types.third_party_app_analytics_link_service import (
    GetThirdPartyAppAnalyticsLinkRequest as GetThirdPartyAppAnalyticsLinkRequest,
    RegenerateShareableLinkIdRequest as RegenerateShareableLinkIdRequest,
    RegenerateShareableLinkIdResponse as RegenerateShareableLinkIdResponse,
)
from google.ads.googleads.v8.services.types.topic_constant_service import (
    GetTopicConstantRequest as GetTopicConstantRequest,
)
from google.ads.googleads.v8.services.types.topic_view_service import (
    GetTopicViewRequest as GetTopicViewRequest,
)
from google.ads.googleads.v8.services.types.user_data_service import (
    UploadUserDataRequest as UploadUserDataRequest,
    UploadUserDataResponse as UploadUserDataResponse,
    UserDataOperation as UserDataOperation,
)
from google.ads.googleads.v8.services.types.user_interest_service import (
    GetUserInterestRequest as GetUserInterestRequest,
)
from google.ads.googleads.v8.services.types.user_list_service import (
    GetUserListRequest as GetUserListRequest,
    MutateUserListResult as MutateUserListResult,
    MutateUserListsRequest as MutateUserListsRequest,
    MutateUserListsResponse as MutateUserListsResponse,
    UserListOperation as UserListOperation,
)
from google.ads.googleads.v8.services.types.user_location_view_service import (
    GetUserLocationViewRequest as GetUserLocationViewRequest,
)
from google.ads.googleads.v8.services.types.video_service import (
    GetVideoRequest as GetVideoRequest,
)
from google.ads.googleads.v8.services.types.webpage_view_service import (
    GetWebpageViewRequest as GetWebpageViewRequest,
)
